/**
 * @file
 * @brief channel group class definition
 * @author Miroslav Kubelik
 * @date 2007
 */

#ifndef CHANGRP_H
#define CHANGRP_H

//neccesary includes for class definition
#include <string>
#include <vector>

//just forward declaration - vector<SerialIface>& is reference
class GIface;

/**
 * @brief class for the channel group in the E1 PDH container
 */
class Changrp
{
 private:
  int mID;
  /**
   * @brief timeslot range
   * Timeslot range for this channel group e.g. 1-31 1-10,16
   */
  std::string mTSrange;
  /**
   * @brief serial interface
   *
   * Copy of Serial interface, which belog to this channel group.
   */     
  GIface* mpSerIface;
  /*
  * @brief corresponding controller ID
  */  
  std::string mContrID;

 public:
  //constructor
  Changrp(int id, const std::string& range): mID(id),
      mTSrange(range),
      mpSerIface(NULL),
      mContrID("")
  {}
  
  /**
   * copy constructor, nedded if use "dynamic memory" structures
   * in class members (e.g. vector of pointers, arrays of pointers)
  */
  Changrp(const Changrp& copiing);
  ~Changrp();
  int getID() const {return mID;}
  void setContrID(std::string str) {mContrID=str;}
  std::string getContrID() const {return mContrID;}
  std::string getTSrange() const {return mTSrange;}
  /** @brief make "connection" between serial interface and channel group
   */
  bool makeSerIfacelink(std::vector<GIface>& rSerIfacesV);
  /** @brief check if serial id is for our channel group
   */
  bool isSerID(std::string serID);
  /**
   * @brief get corresponded serial interace
   *
   * Inspect function return const pointer to binded GIface, GIface cannot be
   * changed via this pointer.
   */      
  const GIface* getSerIface() const { return mpSerIface; }
  /** @brief return serial interface identifier for our channel group */
  std::string makeSerID();
  /** @brief return a count of used timeslosts */
  unsigned int getUsedTSCount() const;
  /** @brief get count of used timeslosts from one timeslot range*/
  static unsigned int getUsedTSFromTSRange(std::string& tsRange);
};

#endif
