/**
 * @file
 * @brief implementation of the CiscoBoxSummary class
 * @author Miroslav Kubelik
 * @date August 2007
 */

//STDC++ and STL Headers

//C and local headers
#include "CiscoBoxSummary.h"
#include "CiscoBox.h"

using namespace std;

//---------------------------------------------------------------------------
/**
 * @brief constructor for a creating summary from the CiscoBox instance
 */
CiscoBoxSummary::CiscoBoxSummary(const CiscoBox& rCiscoBox): mE1Summary(),mE3Summary(),mSonetSummary(),mWholeSyncSummary()
{
 makeE1Summary(rCiscoBox);
 makeE3Summary(rCiscoBox);
 makeSonetSummary(rCiscoBox);

 //create whole summary for the synchronous technologies
 mWholeSyncSummary.addFromSummary(mE1Summary,true);
 mWholeSyncSummary.addFromSummary(mE3Summary,true);
 mWholeSyncSummary.addFromSummary(mSonetSummary,true);
}

//---------------------------------------------------------------------------
/**
 * @brief make E1 summary for the conrete CiscoBox
 */
void CiscoBoxSummary::makeE1Summary(const CiscoBox& rCiscoBox)
{
 //const reference to vector of all E1 controllers
 const vector<E1Controller>& rE1ContrV=rCiscoBox.getAllE1();

 //iterator must be const
 for (vector<E1Controller>::const_iterator iter=rE1ContrV.begin();iter<rE1ContrV.end();iter++)
 {
  //summary for the concrete E1
  SyncSummary oneControllerSum(*iter);
  mE1Summary.addFromSummary(oneControllerSum,true);
 }
}

//---------------------------------------------------------------------------
/**
 * @brief make E3 summary for the conrete CiscoBox
 */
void CiscoBoxSummary::makeE3Summary(const CiscoBox& rCiscoBox)
{
 //const reference to vector of all E3 controllers
 const vector<E3Controller>& rE3ContrV=rCiscoBox.getAllE3();

 //iterator must be const
 for (vector<E3Controller>::const_iterator iter=rE3ContrV.begin();iter<rE3ContrV.end();iter++)
 {
  //summary for the concrete E3
  SyncSummary oneControllerSum(*iter);
  mE3Summary.addFromSummary(oneControllerSum,true);
 }
}

//---------------------------------------------------------------------------
/**
 * @brief make Sonet summary for the conrete CiscoBox
 */
void CiscoBoxSummary::makeSonetSummary(const CiscoBox& rCiscoBox)
{
 //const reference to vector of all Sonet controllers
 const vector<SonetController>& rSonetContrV=rCiscoBox.getAllSonet();

 //iterator must be const
 for (vector<SonetController>::const_iterator iter=rSonetContrV.begin();iter<rSonetContrV.end();iter++)
 {
  //summary for the concrete Sonet
  SyncSummary oneControllerSum(*iter);
  mSonetSummary.addFromSummary(oneControllerSum,true);
 }
}
