/**
 * @file
 * @brief declaration of the CiscoBoxSummary class
 * @author Miroslav Kubelik
 * @date August 2007
 */

#ifndef CISCOBOXSUMMARY_H
#define CISCOBOXSUMMARY_H

/* forward declaration - for pointers and references */
class CiscoBox;

/* necessary declaration for class definition */
#include "SyncSummary.h"

/**
 * @brief class for the one Cisco device summary statists
 *
 * A class can contain a different kind of summaries e.g.
 *  - synchronous summaries (for SDH/PDH controllers)
 *  - ethernet summaries
 *  - ...
 */
class CiscoBoxSummary
{
 protected:
  /** @brief summary for all E1s */
  SyncSummary mE1Summary;
  /** @brief summary for all E3s */
  SyncSummary mE3Summary;
  /** @brief summary for all Sonets */
  SyncSummary mSonetSummary;
  /** @brief summary for all synchronous technologies */
  SyncSummary mWholeSyncSummary;

 public:
  /** @brief empty constructor, just create all empty summaries */
  CiscoBoxSummary(): mE1Summary(),mE3Summary(),mSonetSummary(),mWholeSyncSummary() {}
  /** @brief constructor for a creating summary from the CiscoBox instance*/
  CiscoBoxSummary(const CiscoBox& rCiscoBox);

  /** @brief destructor */
  virtual ~CiscoBoxSummary() {}
  
  //inspect getters, return const objects
  const SyncSummary& getE1Summary() const {return mE1Summary; }
  const SyncSummary& getE3Summary() const {return mE3Summary; }
  const SyncSummary& getSonetSummary() const {return mSonetSummary; }
  const SyncSummary& getWholeSyncSummary() const {return mWholeSyncSummary; }

  /** @brief make E1 summary for the conrete CiscoBox */
  void makeE1Summary(const CiscoBox& rCiscoBox);
  /** @brief make E3 summary for the conrete CiscoBox */
  void makeE3Summary(const CiscoBox& rCiscoBox);
  /** @brief make Sonet summary for the conrete CiscoBox  */
  void makeSonetSummary(const CiscoBox& rCiscoBox);
};

#endif
