/**
 * @file
 * @brief declaration of the CiscoconfParser class
 * @author Miroslav Kubelik
 * @date 2007
 */
 
#ifndef CISCOCONFPARSER_H
#define CISCOCONFPARSER_H

/* necessary includes with types for this class declation */
#include <string>
#include <istream>

/* necessary forward class declations */
class CiscoBox;
class E1Controller;
class GIface;

/**
 * @brief Cisco device configuration parser class
 */
class CiscoconfParser
{
 private:
  /** @brief state parser flag, uses static const public members*/
  unsigned int mStatus;
  /** @brief pointer to the one cisco box */
  CiscoBox*  mpCiscoBox;

  GIface* factoryIfObj(std::string& line);
  Controller* factoryContrObj(std::string& line);
  void parsedevinfo(std::string& rline);
 
 public:
  const static unsigned int PARS_STATUS_UNDEF;
  const static unsigned int PARS_STATUS_CONTR;
  const static unsigned int PARS_STATUS_IFACE;
  
  CiscoconfParser();
  ~CiscoconfParser();

  void parse(std::istream& rInS);
  static bool isBegContr(std::string& rline);
  static bool isEndSection(std::string& rline);
  CiscoBox* getCiscoBox(){ return mpCiscoBox; }
};

#endif
