/*
 implementation of Controller class
*/

//STDC++ and STL Headers
#include <string>
#include <iostream>
#include <typeinfo>

//C and local headers
#include "regexp/regexp/Matcher.h"
#include "regexp/regexp/Pattern.h"
#include "Controller.h"
#include "Utils.h"

using namespace std;

//---------------------------------------------------------------------------
/**
 * get circuit identifier (e.g TR1234) from description
 * testing for group of patterns match
 * examples:
 * GTSN style ## SL1234 ##
 * NEXTRA style pr=GTS:ci=GN44539:ms=m:us=o:id=1061839:nm=prefa_herspice
 */
std::string Controller::getCID(std::string str)
{
 
 Pattern* pPattern=NULL;
 Matcher* pMatcher=NULL;
 //vector with regexp patterns
 vector<string> PatternsV;
 //store for return string, must be used, because regexp objects must be deleted
 //before return 
 string retstr("");
 string patternName;
 
 /* pattern for GTS style description */
 patternName="GTSNclassic";
 Pattern::registerPattern(patternName,"## ([A-Za-z]{2})([0-9]{3,}) ##");
 PatternsV.push_back(patternName);
 
 /* pattern for Nextra style description */
 patternName="Nextra";
 Pattern::registerPattern(patternName,"pr=GTS:(?:ci|pi)=([A-Za-z]{2})([0-9]{3,})");
 PatternsV.push_back(patternName);
 
 for(vector<string>::iterator iter=PatternsV.begin();iter<PatternsV.end();iter++) {
  patternName=*iter;
  pPattern=Pattern::compile("{"+patternName+"}");
  pMatcher = pPattern->createMatcher(str);
  if (pMatcher->findFirstMatch()) {
   //cout << "CID line " << str << " matched " << endl;
   string circstr=pMatcher->getGroup(1);
   circstr=Utils::upperCase(circstr);
   //cout << "circuit string " << circstr << endl;
   string circid=pMatcher->getGroup(2);
   circid=Utils::upperCase(circid);
   //cout << "circuit ID " << circid << endl;
   if (checirctype(circstr)) retstr=circstr+circid;
  }
  delete pPattern;delete pMatcher;
  if (!retstr.empty()) {
   break;
  }
 }

 return retstr;
}

//---------------------------------------------------------------------------
/**
 * get binded circuit identifier (e.g TR1234) from description like "<>SL1234 ## TR567<>##"
 */
std::string Controller::getBID(std::string str)
{
 Pattern* pPattern=NULL;
 Matcher* pMatcher=NULL;
 string retstr("");
 
 pPattern=Pattern::compile(" ([A-Za-z]{2})([0-9]{3,}) ## [A-Za-z]{2}[0-9]{3,} ##");
 pMatcher = pPattern->createMatcher(str);
 if (pMatcher->findFirstMatch()) {
  //cout << "BID line " << str << " mathed " << endl;
  string circstr=pMatcher->getGroup(1);
  circstr=Utils::upperCase(circstr);
  //cout << "circuit string " << circstr << endl;
  string circid=pMatcher->getGroup(2);
  circid=Utils::upperCase(circid);
  //cout << "BID:" << circid << endl;
  if (checirctype(circstr)) retstr=circstr+circid;
 }
 delete pPattern;delete pMatcher;
 return retstr;
}

/**
 * check, if circuit identifier has correct form
 */
bool Controller::checirctype(std::string str)
{
 if (str=="TR") return true;
 else if (str=="GN") return true;
 else if (str=="SL") return true;
 else if (str=="NP") return true;
 else return false;
}
