/*
 Generic Interface class declaration
*/

#ifndef GIFACE_H
#define GIFACE_H

//necessary includes for the class definition
#include <vector>
#include <string>
#include "Controller.h"

//forward declaration
class GSubif;
class CiscoBox;

#define GIFACE_SERIALSTR "Serial"
#define GIFACE_ATMSTR "ATM"
#define GIFACE_POSSTR "POS"

/**
 * base class for the any interface on the device
 *
 * class must be inherit Controller class as virtual, because we will inherit
 * next classes from GIface and Controller class must be in these only once
 */ 
class GIface: public virtual Controller
{
 private:
  bool mHaveSubIf;
  std::vector<GSubif*> mSubIfVp;
   
  protected:
  /**
   * determinate interface in config -  Serial for serial ifaces, Ethernet for
   * ethernet ifaces etc.
   */
  std::string mConfIfDeter;
  std::string mIPaddr;
  
  virtual void setType();
   
 public:
  GIface();
  GIface(std::string iftype);
  GIface(const GIface& m);
  virtual ~GIface();
  static GIface* CreateIface(std::string& rline,CiscoBox* pCiscoBox,std::string iftype);
  static ContrType getMapType(std::string str);
  static void trimIfaceIDstrline(std::string& ifaceline,std::string iftype);
  void setIPaddr(const std::string& str) {mIPaddr=str;}
  void setHaveSubIf(bool val) {mHaveSubIf=val;}
  bool getHaveSubIf() const {return mHaveSubIf;}
  virtual void setConfIfDeter(std::string str);
  std::string getIPaddr() const {return mIPaddr;}
  const std::vector<GSubif*>& getAllSubIfV() const { return mSubIfVp; }
  /**
   * this method must de overloaded - is declared as pure virtual method in Controller base class
   */   
  virtual void parsContrSection(std::string& rline) { this->parsSerSection(rline); }
  virtual void parsSerSection(std::string& rline);
  void addCopySubifp(GSubif* pSubif);
  void printDebuginfo();
};

#endif
