/*
* implementation of Serial Subinterface class
*/

//STDC++ and STL Headers
#include <iostream>
#include <string>
#include <stdexcept>

//C and local headers
#include "regexp/regexp/Matcher.h"
#include "regexp/regexp/Pattern.h"
#include "GSubif.h"
#include "Utils.h"

using namespace std;

//---------------------------------------------------------------------------
/**
 * copy constructor, nedded if ve can push_back this class with pointer to vector
 */
GSubif::GSubif(const GSubif& m) : Controller(m),GIface(m)
{
 //cout << "copy const for SerSubif " << m.mName << endl;
 mSubifID=m.mSubifID;
}

void GSubif::setType()
{
 //cout << __PRETTY_FUNCTION__ << endl;
 ContrType type=GSubif::getMapType(mConfIfDeter);
 if (type == eUndef) {
  throw logic_error("GSubif::setType - can't set Iface type, unknow determinant "+mConfIfDeter);
  return;
 } else {
  mType=type;
 }
}

/**
 * get ContrType (defined in base Controller class), which is corresponding to
 * interfece type string in configuration (e.g Serial, ATM ...)
 */   
ContrType GSubif::getMapType(std::string str)
{
 //cout << __PRETTY_FUNCTION__ << "(" << str << ")" << endl;
 if (str == GIFACE_SERIALSTR) {
  return eSerialSubif;
 }
 if (str == GIFACE_ATMSTR) {
  return eATMSubif;
 }
 if (str == GIFACE_POSSTR) {
  return ePOSSubif;
 }
 return eUndef;
}

//---------------------------------------------------------------------------
/**
 * get main interface ID from subinterface definition line (e.g. interface Serial2/1/2:13.16 point-to-point)
 * @param iftype string type of subinterface (ATM,Serial ...)
 * @param IfaceIDline subinterface ID line see above
 * @return main interface line string (2/1/2:13 for our example) or empty string
 */ 
std::string GSubif::getMainIfIDfromIfaceline(std::string iftype,std::string IfaceIDline)
{
 string retval="";

 if (iftype.empty()) {
  cout << __PRETTY_FUNCTION__ << "Error: empty iftype - interface config interface determinant " << endl;
  return  ""; 
 }
 
 //trim all over interface ID (e.g Serial1/0/1:0.12 point-to-point -> Serial1/0/1:0.12)
 //if any
 GIface::trimIfaceIDstrline(IfaceIDline,iftype);

 //get main interface
 //end $ is needed, we can use by reason of call trimIfaceIDstrline
 string pattern=iftype+"([\\d:./]+)\\.\\d+$";
 Pattern* pPattern=Pattern::compile(pattern);
 Matcher* pMatcher = pPattern->createMatcher(IfaceIDline);
 if (pMatcher->findFirstMatch()) {
  //cout << "GSubif::getMainIfIDfromIfaceline MainIF " << pMatcher->getGroup(1) << " detect in subif " << IfaceIDline << endl;
  retval=pMatcher->getGroup(1);
 } else {
  //cout << "GSubif::getMainIfIDfromIfaceline not detect MainIF in line " << IfaceIDline << endl;
 }
 delete pPattern;delete pMatcher;
 return retval;
}

//---------------------------------------------------------------------------
/**
 * get main interface ID from subif name GSubif::mName (e.g. 2/1/2:13.16)
 * @return main interface line string (2/1/2:13 for our example) or empty string 
 */ 
std::string GSubif::getMainIfID()
{
 if (mConfIfDeter.empty()) {
  cout <<__PRETTY_FUNCTION__ <<  " Error: empty mConfIfDeter - interface config interface determinant " << endl;
  return ""; 
 }
 if (getName().empty()) {
  cout <<__PRETTY_FUNCTION__ << " Error: empty mName" << endl;
  return ""; 
 }
 
 string retval="";
 //end $ is needed
 Pattern* pPattern=Pattern::compile("([\\d:./]+)\\.\\d+$");
 Matcher* pMatcher = pPattern->createMatcher(getName());
 if (pMatcher->findFirstMatch()) {
  //cout << "MainIf " << pMatcher->getGroup(1) << " detect in subif name " << getName() << endl;
  retval=pMatcher->getGroup(1);
 } else {
  //cout << "MainIf not detect in name " << getName() << endl;
 }
 delete pPattern;delete pMatcher;
 return retval;
}

/**
 * parse configuration lines, including start subinterface section line
 * (e.g. interface Serial1/0/1.16 point-to-point)  
 */
void GSubif::parsSerSection(std::string& rline)
{
 if (mConfIfDeter.empty()) {
  throw logic_error("GSubif::parsSerSection - unknown configuration type determinant, can't parse");
  return;
 }
  //cout << "GSubif::parsSerSection " << rline << endl;
   
 /* we need make our parse code before base class parsing, because
    in base class in is used "stop after match" method
 */
 Pattern* pPattern=NULL;
 Matcher* pMatcher=NULL;

 //get subinterface id
 if (Utils::regFirstMatch("^interface ",rline)) {
  //help string, because GIface::trimIfaceIDstrline modified string reference 
  string helpstr(rline);
  //trim all over interface ID (e.g Serial1/0/1:0.12 point-to-point -> Serial1/0/1:0.12)
  //NEEDED
  GIface::trimIfaceIDstrline(helpstr,mConfIfDeter);
  //end $ is needed, we can use by reason of call trimIfaceIDstrline 
  string pattern=mConfIfDeter+"[\\d:./]+\\.(\\d+)$";
  pPattern=Pattern::compile(pattern);
  pMatcher = pPattern->createMatcher(helpstr);
  if (pMatcher->findFirstMatch()) {
   //cout << "SubifID matched " << pMatcher->getGroup(1) << endl;
   mSubifID=pMatcher->getGroup(1);
  }
  delete pPattern;delete pMatcher;
 } 
 
 /* don't stop parser, we will parse interface id, description ... 
    in base (GIface) class.
 */ 
  
 GIface::parsSerSection(rline);
}
