/**
 * @file
 * @brief declaration of the SyncSummary class
 * @author Miroslav Kubelik
 * @date July 2007
 */

#ifndef SYNCSUMMARY_H
#define SYNCSUMMARY_H

/* necessary declaration for class definition */

/* forward declaration - for pointers and references */
class E1Controller;
class E3Controller;
class SonetController;

/**
 * @brief class for the summary for the synchronous elements
 *
 * E.g. E1,E3,STM-1
 */
class SyncSummary
{
 private:
  unsigned int mAllTimeslots;
  unsigned int mFreeTimeslots;
  unsigned int mAllE1s;
  unsigned int mFreeE1s;
  unsigned int mChannelGroups;

  /** @brief Add summary content for a free E1.*/
  void addE1FreeSummary(bool addToAll = false);

 public:
  /**@brief empty constructor, just sets to zero all internal statistic properties */
  SyncSummary(): mAllTimeslots(0),
   mFreeTimeslots(0),
   mAllE1s(0),
   mFreeE1s(0),
   mChannelGroups(0)
   {}

  /**@brief constructor for a creating summary from the E1 controller information */
  SyncSummary(const E1Controller& e1Contr);
  /** @brief constructor for a creating summary from the E3 controller information */
  SyncSummary(const E3Controller& e3Contr);
  /** @brief constructor for a creating summary from the Sonet controller information */
  SyncSummary(const SonetController& sonetContr);

  /**@brief empty desctructor */
  virtual ~SyncSummary() {}

  //properties getters
  unsigned int getAllTimeslots() const { return mAllTimeslots; }
  unsigned int getFreeTimeslots() const { return mFreeTimeslots; }
  unsigned int getUsedTimeslots() const { return (mAllTimeslots - mFreeTimeslots); }
  unsigned int getAllE1() const { return mAllE1s; }
  unsigned int getFreeE1() const { return mFreeE1s; }
  unsigned int getUsedE1() const { return (mAllE1s - mFreeE1s); }
  unsigned int getChannelGroups() const { return mChannelGroups; }
  
  /** @brief Add content of the other summary to our summary. */
  void addFromSummary(const SyncSummary& summary, bool addToAll=false);

  /** @brief just debug print */
  void printDebuginfo() const;
};

#endif
