/**
 * @file
 * @ingroup Programs
 * @brief the portinfo XML configuration class implementation
 * @author Miroslav Kubelk
 * @date 2007
 */
 
//STDC++ and STL Headers
#include <fstream>
#include <sstream>
#include <stdexcept>
#include <iostream>

//C and local headers
#include "PortinfoXMLConfig.h"
#include "xmlParser/xmlParser.h"

using namespace std;

//------------------------------------------------------------------------------
/**
 * Read the portinfo XML configuration from the XML file
 */
void PortinfoXMLConfig::readFromFile(const std::string& fileName)
{
 ifstream inFileStrm;

  //if cannot open a file with the device configuration get an exception
 inFileStrm.open(fileName.c_str());
 while(inFileStrm.good() == false) throw runtime_error("Error: Unable to open file "+fileName);
 
 XMLNode xMainNode=XMLNode::openFileHelper(fileName.c_str(),"config");

 mDevConfDir=xMainNode.getChildNode("devicesConfigDir").getText();
 mReportDir=xMainNode.getChildNode("reportDir").getText();
 mMediaDir=xMainNode.getChildNode("mediaDir").getText();
  
 //devices
 XMLNode xNode=xMainNode.getChildNode("devices");
 int itemCount=xNode.nChildNode("device");
 for (int i=0; i<itemCount; i++) {
  deviceT dev;
  dev.id=xNode.getChildNode("device",i).getAttribute("id");
  dev.ipAddr=xNode.getChildNode("device",i).getAttribute("ipaddr");
  mDevices.push_back(dev);
 }

 //groups
 xNode=xMainNode.getChildNode("groups");
 itemCount=xNode.nChildNode("group");
 for (int i=0; i<itemCount; i++) {
  groupT gr;

  //one group node
  XMLNode xGrNode = xNode.getChildNode("group",i);
  gr.name=xGrNode.getAttribute("name");
  gr.report=xGrNode.getChildNode("report").getText();

  //get members
  int memberCount=xGrNode.nChildNode("member");
  for (int i=0; i<memberCount; i++) {
   XMLNode xMembNode = xGrNode.getChildNode("member",i);
   gr.members.push_back( getDevicebyId(xMembNode.getText()) );
  }
  mGroups.push_back(gr);
 }

}

//------------------------------------------------------------------------------
PortinfoXMLConfig::deviceT PortinfoXMLConfig::getDevicebyId(const std::string& devId)
{
 for (vector<deviceT>::const_iterator iter=mDevices.begin();iter<mDevices.end();iter++) {
  if (iter->id == devId) {
   //copy of the found deviceT object, implicit copy constructor called, be aware!
   deviceT dev = (*iter);
   return dev;
  }
 }

 ostringstream osstrm;
 osstrm << "Cannot find the device by id : " << devId << " in the XML configuration";
 throw runtime_error(osstrm.str());
}
