/**
 * @file
 * @ingroup Programs
 * @brief the portinfo XML configuration class definitions
 * @author Miroslav Kubelk
 * @date 2007
 */

#ifndef PORTINFOXMLCONFIG_H
#define PORTINFOXMLCONFIG_H

/* necessary declaration for class definition */
#include <string>
#include <vector>

/* forward declaration - for pointers and references */

/**
 * @brief portinfo XML config class
 *
 * A class which encapsulates operations and structures for the portinfo
 * XML configuration
 */
class PortinfoXMLConfig
{
  public:
   /** @brief one device structure*/
   struct deviceT {
    std::string id;
    std::string ipAddr;
    /** @brief empty device constructor */
    deviceT():id(""),ipAddr("") {}
   };

   /* @brief one group structure*/
   struct groupT {
    std::string name;
    std::string report;
    std::vector<deviceT> members;
    /** @brief empty group constructor */
    groupT():name(""),report(""),members() {}
   };

  private:
   std::string mDevConfDir;
   std::string mReportDir;
   std::string mMediaDir;
   std::vector<deviceT> mDevices;
   std::vector<groupT> mGroups;

  public:
   PortinfoXMLConfig():mDevConfDir(""),mReportDir(""),mMediaDir(""),
    mDevices(),mGroups()
   {}

  ~PortinfoXMLConfig() {}

   //getters
   std::string getDevConfDir() { return mDevConfDir; }
   std::string getReportDir() { return mReportDir; }
   std::string getMediaDir() { return mMediaDir; }
   /** @brief  inspect function for the devices, return const reference for the vector */
   const std::vector<deviceT>& getDevices() const { return mDevices; }
   /** @brief  inspect function for the groups, return const reference for the vector */
   const std::vector<groupT>& getGroups() const { return mGroups; }

   /** @brief read XML configuration file */
   void readFromFile(const std::string& fname);
   /** @brief get device, which is defined in the device XML configuration definition */
   deviceT getDevicebyId(const std::string& devId);
};

#endif
