/**
 * @file
 * @brief implementation for the portinfo xml export class for the channel-group
 * @author Miroslav Kubelik
 * @date 2007
 */

//STDC++ and STL Headers 
#include <sstream>
#include <stdexcept>

using namespace std;

//C and local headers
#include "CiscoChngr.h"
#include "Changrp.h"
#include "GIface.h"
#include "Utils.h"

//------------------------------------------------------------------------------
/**
 * constructor, create XML Node
 */
Portinfo::CiscoChngr::CiscoChngr()
{
 mSpXMLNode=XMLNode::parseString(string("<channelgrp/>").c_str());
}

//---------------------------------------------------------------------------
/**
 * return XMLNode for one channel group object 
 */
XMLNode Portinfo::CiscoChngr::getXMLnode(const Changrp& rChangrp)
{
 const GIface* pSerIface=rChangrp.getSerIface();
 
 //add id
 mSpXMLNode.addAttribute("id", Utils::inttostr(rChangrp.getID()).c_str() );

 if (pSerIface!=NULL) {
  //cout << "Changrp::nrmXMLnode: exporting iface: ";
  //pSerIface->printDebuginfo();

  //add serial id
  XMLNode xSubNode=mSpXMLNode.addChild("serialid");
  xSubNode.addText( pSerIface->getName().c_str() );

  //add description
  xSubNode=mSpXMLNode.addChild("descr");
  xSubNode.addText( pSerIface->getDescr().c_str() );

  //add ip address
  xSubNode=mSpXMLNode.addChild("ipaddr");
  xSubNode.addText( pSerIface->getIPaddr().c_str() );

  //add timeslost range descriptor
  mSpXMLNode.addAttribute("ts",rChangrp.getTSrange().c_str());
 } else {
  ostringstream osstrm;
  osstrm << __PRETTY_FUNCTION__ << " - Serial Interface for channel group isn't set!"; 
  throw logic_error(osstrm.str());
 }

 return mSpXMLNode; 
}
