/**
 * @file
 * @brief the portinfo cisco device group implementation
 * @author Miroslav Kubelik
 * @date 2007
 */

//STDC++ and STL Headers

//C and local headers
#include "CiscoDevGroup.h"
#include "CiscoDev.h"
#include "XMLSummaryConvertor.h"
#include "Utils.h"

using namespace std;

//---------------------------------------------------------------------------
/**
 * Copy of the CiscoBox object is added to group. Correct copy
 * constructor for the CiscoBox class must be defined.
 * Copy constructor is used by push_back vector method.
 */
void Portinfo::CiscoDevGroup::addCiscoBox(const CiscoBox& rCiscoBox)
{
 mCiscoBoxV.push_back(rCiscoBox);
}

//------------------------------------------------------------------------------
/**
 * get portinfo XML for a whole group of cisco devices as XMLNode object
 */
XMLNode Portinfo::CiscoDevGroup::getXMLNode() const
{
 XMLNode xMainNode=XMLNode::createXMLTopNode("xml",true);
 xMainNode.addAttribute("version","1.0");
 xMainNode.addAttribute("encoding","iso-8859-1");

 XMLNode xMeta=xMainNode.addChild("meta",true);
 xMeta.addAttribute("name","GENERATOR");
 xMeta.addAttribute("content","C++ xmlParser by Frank Vanden Berghen v.2.14");

 //"routers" node
 XMLNode xRoutersNode=xMainNode.addChild("routers");

 //"report" subnode node
 XMLNode xSubNode=xRoutersNode.addChild("report");

 //add localtime
 time_t rawtime;
 time ( &rawtime );
 string timestr(ctime (&rawtime));
 Utils::trim(timestr,"\n");
 xSubNode.addAttribute("created",timestr.c_str());

 xSubNode.addAttribute("name",mName.c_str());

 //add router nodes
 for(vector<CiscoBox>::const_iterator piterCiscoBox=mCiscoBoxV.begin();piterCiscoBox<mCiscoBoxV.end();piterCiscoBox++)
 {
  xRoutersNode.addChild( Portinfo::CiscoDev::getXMLNode(*piterCiscoBox) );
 }

 //add whole group summary
 xRoutersNode.addChild( getXMLSummary() );

 return xMainNode;
}

//------------------------------------------------------------------------------
std::string Portinfo::CiscoDevGroup::getXMLexport() const
{
 char* t=this->getXMLNode().createXMLString();
 string retstr(t);
 free(t);
 return retstr;
}

//------------------------------------------------------------------------------
/**
 * return XML object for a summary for a whole group of device
 */
XMLNode Portinfo::CiscoDevGroup::getXMLSummary() const
{
 return XMLSummaryConvertor::getXMLCiscoBoxSummary(mSummary);
}

//------------------------------------------------------------------------------
/** Fill a member summary object - mSummary through all device summaries.
 */
void Portinfo::CiscoDevGroup::createSummary()
{
 //add device summaries
 for(vector<CiscoBox>::const_iterator piterCiscoBox=mCiscoBoxV.begin();piterCiscoBox<mCiscoBoxV.end();piterCiscoBox++)
 {
  CiscoBoxSummary boxSum(*piterCiscoBox);
  mSummary.addCiscoBoxSummary(boxSum);
 }
}

