/**
 * @file
 * @brief the portinfo cisco device group exporter
 * @author Miroslav Kubelik
 * @date 2007
 */

#ifndef PORTINFO_CISCODEVGROUP_H
#define PORTINFO_CISCODEVGROUP_H

/* necessary declaration for class definition */
#include <vector>
#include <string>
#include "CiscoBox.h"
#include "CiscoDevGroupSummary.h"
#include "xmlParser/xmlParser.h"

/* forward declaration - for pointers and references */

namespace Portinfo
{
 class CiscoDevGroup
 {
  private:
   /** @brief group name
    * It's reportname in the XML export
    */
   std::string mName;
   std::vector<CiscoBox> mCiscoBoxV;
   CiscoDevGroupSummary mSummary;
  public:
   //constructor, create empty group
   CiscoDevGroup(): mName(""),mCiscoBoxV(),mSummary() {}
   //desctructor
   ~CiscoDevGroup(){ mCiscoBoxV.clear(); }
   void setName(const std::string& name) {mName=name;}
   std::string getName() const {return mName;}

   /**@brief return a XML export object for a whole group*/
   std::string getXMLexport() const;
   /** @brief return XML object for a whole group */
   XMLNode getXMLNode() const;
   /** @brief return XML object for group summary*/
   XMLNode getXMLSummary() const;
   /** @brief inspect function for the summary*/
   const CiscoDevGroupSummary& getGroupSummary() const { return mSummary; }
   /** @brief add copy of one CiscoBox to our vector*/
   void addCiscoBox(const CiscoBox& rCiscoBox);
   /** @brief create group summary */
   void createSummary();
 };
};

#endif
