/**
 * @file
 * @brief implementation for the portinfo xml export class for the E1 controller
 * @author Miroslav Kubelik
 * @date 2007
 */
 
//STDC++ and STL Headers

//C and local headers
#include "CiscoE1Contr.h"
#include "CiscoChngr.h"
#include "E1Controller.h"

using namespace std;

//------------------------------------------------------------------------------
/**
 * constructor, create XML Node
 */
Portinfo::CiscoE1Contr::CiscoE1Contr()
{
 mSpXMLNode=XMLNode::parseString("<controller/>");
}

//---------------------------------------------------------------------------
/**
 * return XMLNode for one E1 Controller object
 *
 * Empty E1 controllers are exported as <controller> node with empty
 * <channelgrps/> subnode
 */
XMLNode Portinfo::CiscoE1Contr::getXMLnode(const E1Controller& rE1contr)
{
 //add id
 mSpXMLNode.addAttribute("id", rE1contr.getName().c_str() );
 //add description
 mSpXMLNode.addAttribute("description", rE1contr.getDescr().c_str() );
 //add framing
 if ( !rE1contr.getFraming().empty() ) {
  mSpXMLNode.addAttribute("framing", rE1contr.getFraming().c_str() );
 }
 //add clock source
 if ( !rE1contr.getClockSrc().empty() ) {
  mSpXMLNode.addAttribute("clock", rE1contr.getClockSrc().c_str() );
 }

 //const reference to vector of all Channelgroups
 const vector<Changrp>& rChangrpV=rE1contr.getAllChangr();
 //add all channel groups node,
 mSpXMLNode.addChild( Portinfo::CiscoE1Contr::getXMLnodeChannelGroups(rChangrpV) );

 return mSpXMLNode;
} 

//---------------------------------------------------------------------------
/**
 * Export channel groups as XMLNode in one E1 Controller.
 *
 * If a E1 controller has no channel groups, rChangrpV has zero size, in this case
 * return empty <channelgrps/> node, otherwise <channelgrps> has subnodes for each channel
 * group.
 */
XMLNode Portinfo::CiscoE1Contr::getXMLnodeChannelGroups(const std::vector<Changrp>& rChangrpV)
{
  XMLNode xAllChangrNode=XMLNode::parseString("<channelgrps/>");
  for (vector<Changrp>::const_iterator iter=rChangrpV.begin();iter<rChangrpV.end();iter++)
  {
   Portinfo::CiscoChngr ExpChangrp;
   xAllChangrNode.addChild( ExpChangrp.getXMLnode(*iter) );
  }
  return xAllChangrNode;
}
