/**
 * @file
 * @brief implementation for the portinfo xml export class for the E3 controller
 * @author Miroslav Kubelik
 * @date 2007
 */
 
//STDC++ and STL Headers

//C and local headers
#include "CiscoE3Contr.h"
#include "CiscoE1Contr.h"
#include "E3Controller.h"
#include "E1Controller.h"

using namespace std;

//------------------------------------------------------------------------------
/**
 * constructor, create XML Node
 */
Portinfo::CiscoE3Contr::CiscoE3Contr()
{
 mSpXMLNode=XMLNode::parseString("<E3controller/>");
}

//---------------------------------------------------------------------------
/**
 * return XMLNode for one E3 Controller object
 */
XMLNode Portinfo::CiscoE3Contr::getXMLnode(const E3Controller& rE3contr)
{
 //add id
 mSpXMLNode.addAttribute("id", rE3contr.getName().c_str() );
 //add description
 mSpXMLNode.addAttribute("description", rE3contr.getDescr().c_str() );

 /* const pointer to array of subE1 - see E3Controller constructor
  * array is ALWAYS filled
  */
 const E1Controller* pE1A=rE3contr.getAllSubE1();
 int numE1count=rE3contr.getSubE1Count();
 for (int i=0;i<numE1count;i++) {
  //one subE1 controller
  const E1Controller& rE1contr=pE1A[i];

  //create export object for subE1
  Portinfo::CiscoE1Contr expE1Contr;

  //empty Name means that subE1 is not initialized in configuration, export as empty node
  if (rE1contr.getName().empty()) {
   //new temporary empty E1 with corrent name, it corresponds with the current empty
   //subE1
   E1Controller emptyE1;
   //i+1 - subE1 id is counted from 1!
   emptyE1.setName( rE3contr.getSubE1Name(i+1) );
   //add exported empty E1 to E3
   mSpXMLNode.addChild( expE1Contr.getXMLnode(emptyE1) );
  } else {
   //add existed exported E1 to E3 controller
   mSpXMLNode.addChild( expE1Contr.getXMLnode(rE1contr) );
  }
 }

 return mSpXMLNode;
}
