/**
 * @file
 * @brief a declaration for a XML convertor for the summary classes
 * @author Miroslav Kubelik
 * @date 2007
 */

#ifndef PORTINFO_XMLSUMMARYCONVERTOR_H
#define PORTINFO_XMLSUMMARYCONVERTOR_H

/* necessary declaration for class definition */
#include <string>
#include "xmlParser/xmlParser.h"

/* forward declaration - for pointers and references */
class CiscoBoxSummary;
class SyncSummary;

namespace Portinfo
{
 /** @brief class for a converting summary classes to the portinfo XML
  *
  * Currently a convertinf for:
  * - a summary for one cisco device (CiscoBoxSummary)
  * - a generic synchronous summary (SyncSummary)
  */
 class XMLSummaryConvertor
 {
  public:
   /** @brief return XML object for one cisco device summary */
   static XMLNode getXMLCiscoBoxSummary(const CiscoBoxSummary& summary,const std::string& sumName="summary");
   /** @brief return XML object for a generic synchronous summary */
   static XMLNode getXMLSyncSummary(const SyncSummary& sum,const std::string& sumName);
   /** @brief get the utilization as formatted string
    * The utilization is computed during the run of the converting methods. Hence this
    * methods are mostly called from this methods.
    */
   static std::string formatUtilization(float val);
 };
};

#endif
