//configuration from the autoconf
#include "../config.h"

//STDC++ and STL Headers
#include <stdexcept>

//C and local headers
#include "RRDWrap.h"
//rrd library includes
#if HAVE_RRD_CONFIG_H == 1
 #include <rrd_config.h>
#endif
#include <rrd.h>

extern int optind,opterr;

using namespace std;

//------------------------------------------------------------------------------
/** Create the rrd database file
 * @param argArr vector with parameters, which will be passed to the rrd_create
 * library function. Parameters are formated in a form as in the php rrd extension.
 */
void RRDWrap::create(const std::vector<std::string>& argArr)
{
 char **argv;
 unsigned int argc = argArr.size()+3;
 unsigned int i=0;
 
 argv = (char **)malloc(argc * sizeof(char *));

 //first element is a dummy element
 argv[i++] = "dummy";
 //create command
 argv[i++] = strdup("create");
 //filename
 argv[i++] = strdup(mFileName.c_str());

 for (vector<string>::const_iterator iter=argArr.begin();iter<argArr.end();iter++) {
  argv[i++] = strdup(iter->c_str());
 }

 optind=0; opterr=0;
 if ( rrd_test_error() ) rrd_clear_error();

 int status=rrd_create(argc-1, &argv[1]);
 
 //free argv array
 for(i=1;i<argc;i++)
 {
  free(argv[i]);
 }
 free(argv);
 
 if (status != -1) return;
 else {
  string errorStr(rrd_get_error());
  rrd_clear_error();
  throw runtime_error("rrd create error: "+errorStr);
 }
}

//------------------------------------------------------------------------------
/** Update the rrd database file
 * @param opt values string
 */
void RRDWrap::update(const std::string& opt)
{
 char **argv;
 unsigned int argc = 4;
 unsigned int i=0;

 argv = (char **)malloc(argc * sizeof(char *));

 //first element is a dummy element
 argv[i++] = "dummy";
 //update command
 argv[i++] = strdup("update");
 //filename
 argv[i++] = strdup(mFileName.c_str());
 //opt argument
 argv[i++] = strdup(opt.c_str());

 optind=0; opterr=0;
 if ( rrd_test_error() ) rrd_clear_error();

 int status=rrd_update(argc-1, &argv[1]);

 //free arguments array of pointers
 free(argv[1]); free(argv[2]); free(argv[3]);
 free(argv);
 
 if (status != -1) return;
 else {
  string errorStr(rrd_get_error());
  rrd_clear_error();
  throw runtime_error("rrd update error: "+errorStr);
 }
}

//------------------------------------------------------------------------------
/** Create a graph as PNG image from the RRD database.
 * @param argArr vector with parameters, which will be passed to the rrd_graph
 * library function. Parameters are formated in a form as in the php rrd extension.
 */
void RRDWrap::graph(const std::vector<std::string>& argArr)
{
 char **argv,**calcpr;
 unsigned int argc = argArr.size()+2;
 int xsize,ysize;
 double ymin,ymax;
 unsigned int i=0;

 argv = (char **)malloc(argc * sizeof(char *));

 //first element is a dummy element
 argv[i++] = "dummy";
 //create command
 argv[i++] = strdup("graph");

 for (vector<string>::const_iterator iter=argArr.begin();iter<argArr.end();iter++) {
  argv[i++] = strdup(iter->c_str());
 }

 optind=0; opterr=0;
 if ( rrd_test_error() ) rrd_clear_error();

#if HAVE_RRD_12X == 1
 int status=rrd_graph(argc-1, &argv[1], &calcpr, &xsize, &ysize, NULL, &ymin, &ymax);
#else
 int status=rrd_graph(argc-1, &argv[1], &calcpr, &xsize, &ysize);
#endif

 //free argv array
 for(i=1;i<argc;i++)
 {
  free(argv[i]);
 }
 free(argv);

 //the rrd_graph function call was successful
 if (status != -1) {
  //values in the calcp and others variables, which represent parameters for
  //rrd_graph function are currently uninteresting for us, it will maybe change
  //in the future
  //
  //currenty we only free some structures, which are allocated in the rrd_graph
  //function
  if (calcpr) {
	 for (unsigned int i = 0; calcpr[i]; i++) {
    free(calcpr[i]);
   }
   free(calcpr);
  }
  return;
 }
 else {
  string errorStr(rrd_get_error());
  rrd_clear_error();
  throw runtime_error("rrd graph error: "+errorStr);
 }
}
