/**
 * @file
 * @brief E3 controller class tests
 * @author Miroslav Kubelk
 * @date Jul 2007
 */

/* autoheader config */
#include "../src/config.h"

//STDC++ and STL Headers
#include <iostream>
#include <fstream>

//C and local headers
#include "ciscoconf/E3Controller.h"
#include "ciscoconf/SyncSummary.h"

//global variables

//function prototypes
void readE3conf(E3Controller& e3Contr);

/** MAIN entry point*/
int main(int argc, char *argv[])
{
 E3Controller e3Contr;

 readE3conf(e3Contr);
 
 SyncSummary SyncSummary(e3Contr);
 SyncSummary.printDebuginfo();

 std::cout << "testing return values ...";

 if (SyncSummary.getAllTimeslots() ==  512 &&
     SyncSummary.getFreeTimeslots() == 212 &&
     SyncSummary.getUsedTimeslots() == 300 &&
     SyncSummary.getAllE1() == 16 &&
     SyncSummary.getFreeE1() == 3 &&
     SyncSummary.getUsedE1() == 13 &&
     SyncSummary.getChannelGroups() == 45
    ) std::cout << " OK" << std::endl;
 else {
  std::cout << " FALSE" << std::endl;
  exit(EXIT_FAILURE);
 }

 exit(EXIT_SUCCESS);
}

//---------------------------------------------------------------------------
/** read E3 controller configuration from the file gw11.gts.cz-E3.txt
 */
void readE3conf(E3Controller& e3Contr)
{
 std::fstream infile;
 std::string line;
 
 //read header file
 std::string fname="testConf-E3.txt";
 std::cout << "reading config from file: "<< fname << std::endl;
 infile.open(fname.c_str(),std::ios::in);
 if (!infile.good())
 {
  std::cerr << "Error: Can't open file " << fname << std::endl;
  exit(EXIT_FAILURE);
 }

 while(!getline(infile,line).eof())
 {
  e3Contr.parsContrSection(line);
 }
 infile.close();
}
