/**
 * @file
 * @brief Sonet controller class tests
 * @author Miroslav Kubelk
 * @date Jul 2007
 */

/* autoheader config */
#include "../src/config.h"

//STDC++ and STL Headers
#include <iostream>
#include <fstream>

//C and local headers
#include "ciscoconf/SonetController.h"
#include "ciscoconf/SyncSummary.h"

//global variables

//function prototypes
void readSonetconf(SonetController& sonetContr);
void getSubE1NameTest();

/** MAIN entry point*/
int main(int argc, char *argv[])
{
 getSubE1NameTest();
 
 SonetController sonetContr;
 readSonetconf(sonetContr);
 
 SyncSummary SyncSummary(sonetContr);
 SyncSummary.printDebuginfo();

 std::cout << "testing return values ...";

 if (SyncSummary.getAllTimeslots() == 2016 &&
     SyncSummary.getFreeTimeslots() == 573 &&
     SyncSummary.getUsedTimeslots() == 1443 &&
     SyncSummary.getAllE1() == 63 &&
     SyncSummary.getFreeE1() == 17 &&
     SyncSummary.getUsedE1() == 46 &&
     SyncSummary.getChannelGroups() == 48
    ) std::cout << " OK" << std::endl;
 else {
  std::cout << " FALSE" << std::endl;
  exit(EXIT_FAILURE);
 }

 exit(EXIT_SUCCESS);
}

//---------------------------------------------------------------------------
/** read sonet controller configuration from the file gw11.gts.cz-SONET.txt
 */
void readSonetconf(SonetController& sonetContr)
{
 std::fstream infile;
 std::string line;
 
 //read header file
 std::string fname="testConf-SONET.tx";
 std::cout << "reading config from file: "<< fname << std::endl;
 infile.open(fname.c_str(),std::ios::in);
 if (!infile.good())
 {
  std::cerr << "Error: Can't open file " << fname << std::endl;
  exit(EXIT_FAILURE);
 }

 while(!getline(infile,line).eof())
 {
  sonetContr.parsContrSection(line);
 }
 infile.close();
}

//---------------------------------------------------------------------------
/** test for the getSubE1Name
 */
void getSubE1NameTest()
{
 SonetController sonetContr;
 sonetContr.setName("1/0");
 for(int i=0;i<sonetContr.getSubE1Count();i++){
  std::cout << "subE1 name for the E1 " << (i+1) << " : " << sonetContr.getSubE1Name(i+1) << std::endl;
 }
}
