#!/bin/perl -w
#
#replaces some strings in the device configurations
#
use strict;
#use Data::Dumper;

my $state="UNDEF";
my $skipCurrentLine=0;

`rm -f *.tmp`;
open( FILES, "find ./ -name \"router*\" -or -name \"atm*\" -or -name \"*txt\" |" ) or die "cannot open find process: $!";
while (<FILES>) {
 chop $_;
 print "processing $_\n";
 open(ONEFILE,$_);
 my $tempFile=$_.".tmp";
 open(TEMPFILE,">$tempFile") or die "cannot write to temp file $tempFile: $!";
 while (my $line=<ONEFILE>) {
  &checkState($line);
  if ($skipCurrentLine) { next }

  if (&skipLine($line)) { next }

  $line=&replaceHostame($line,$_);
  $line=&replaceEnable($line);
  $line=&replacePassword($line);
  $line=&replaceIOSname($line);
  $line=&replaceDescription($line);
  $line=&replaceIPAddress($line);
  $line=&replaceATMAddress($line);

  print TEMPFILE $line;
 }
 close TEMPFILE;
 close ONEFILE;
 `mv $tempFile $_`;
}
exit(0);


#===============================================================================
#check state by line content
sub checkState
{
 my ( $line ) = @_;
 if ($line =~ /ip vrf/ ) {
  $state="IPVRF";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /class-map/ ) {
  $state="CLASSMAP";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /policy-map/ ) {
  $state="POLICEMAP";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /route-map/ ) {
  $state="POLICEMAP";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /interface Multilink/ ) {
  $state="IFACEMULTILINK";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /interface Loopback/ ) {
  $state="IFACELOOPBACK";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /router ospf/ ) {
  $state="ROUTEROSPF";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /router rip/ ) {
  $state="ROUTERRIP";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /router bgp/ ) {
  $state="ROUTERBGP";
  $skipCurrentLine=1;
  return;
 };
 if ($line =~ /ip access-list/ ) {
  $state="IPACCESSLIST";
  $skipCurrentLine=1;
  return;
 };
 #end section
 if ($line =~ /^!/ ) {
  $state="UNDEF";
  $skipCurrentLine=0;
  return;
 };
}

#===============================================================================
#skip some line
sub skipLine
{
 my ( $line ) = @_;
 if ($line =~ /Last configuration change/ ) { return 1 };
 if ($line =~ /config last updated/ ) { return 1 };
 if ($line =~ /aaa/ ) { return 1 };
 if ($line =~ /ip icmp/ ) { return 1 };
 if ($line =~ /ip tftp/ ) { return 1 };
 if ($line =~ /ip bgp-community/ ) { return 1 };
 if ($line =~ /ip community-list/ ) { return 1 };
 if ($line =~ /ip extcommunity-list/ ) { return 1 };
 if ($line =~ /ip vrf forwarding/ ) { return 1 };
 if ($line =~ /ip tcp header/ ) { return 1 };
 if ($line =~ /ip rtp/ ) { return 1 };
 if ($line =~ /ip ospf/ ) { return 1 };
 if ($line =~ /ip route/ ) { return 1 };
 if ($line =~ /ip prefix-list/ ) { return 1 };
 if ($line =~ /ip access-group/ ) { return 1 };
 if ($line =~ /ip rcmd/ ) { return 1 };
 if ($line =~ /\s*mpls/ ) { return 1 };
 if ($line =~ /\s*no mpls/ ) { return 1 };
 if ($line =~ /tag-switching / ) { return 1 };
 if ($line =~ /hold-queue/ ) { return 1 };
 if ($line =~ /peer neighbor-route/ ) { return 1 };
 if ($line =~ /bandwidth/ ) { return 1 };
 if ($line =~ /service-policy/ ) { return 1 };
 if ($line =~ /cdp / ) { return 1 };
 if ($line =~ /ppp / ) { return 1 };
 if ($line =~ /multilink-/ ) { return 1 };
 if ($line =~ /autonomous-system/ ) { return 1 };
 if ($line =~ /logging/ ) { return 1 };
 if ($line =~ /access-list/ ) { return 1 };
 if ($line =~ /snmp-server/ ) { return 1 };
 if ($line =~ /tacacs-server/ ) { return 1 };
 if ($line =~ /access-class/ ) { return 1 };
 if ($line =~ /rate-limit/ ) { return 1 };
 if ($line =~ /ntp / ) { return 1 };
 return 0;
}

#===============================================================================
#replace hostname line with device name
sub replaceHostame
{
 my ( $line,$deviceName ) = @_;
 if ($line !~ /^hostname/ ) { return $line };
 #remove ./ 
 $deviceName =~ s/\.\///;
 #remove all after firts dot (.), dot included
 $deviceName =~ s/\..*//;
 return "hostname $deviceName\n";
}

#===============================================================================
sub replaceIOSname
{
 my ( $line) = @_;
 if ($line =~ /^boot system flash/ ) {
  return "boot system flash someIos.bin\n";
 }
 if ($line =~ /^boot bootldr/ ) {
  return "boot bootldr bootflash:someBootFile.bin\n";
 }
 return $line;
}

#===============================================================================
#replace enable
sub replaceEnable
{
 my ( $line) = @_;
 if ($line =~ /^enable / ) {
  return "enable secret IDontKnow\n";
 }
 return $line;
}

#===============================================================================
#replace enable
sub replacePassword
{
 my ( $line) = @_;
 if ($line =~ /password / ) {
  $line =~ s/password .*/password somePassword/;
 }
 return $line;
}

#===============================================================================
#replace description
sub replaceDescription
{
 my ( $line) = @_;
 if ($line =~ /description .*/ ) {
  my $generText=&generText();
  $line =~ s/description .*/description $generText/;
 }
 return $line;
}

#===============================================================================
sub replaceIPAddress
{
 #([0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}) 255/
 my ( $line) = @_;
 if ($line =~ /\s*ip address/ ) {
  my $newIpAddr=int(rand(255)).".".int(rand(255)).".".int(rand(255)).".".int(rand(255));
  $line =~ s/ip address .*/ip address $newIpAddr 255.255.255.255/;
  return $line;
 }
 if ($line =~ / ([0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3})/) {
  my $oldIp=$1;
  my $newIpAddr=int(rand(255)).".".int(rand(255)).".".int(rand(255)).".".int(rand(255));
  $line =~ s/$oldIp/$newIpAddr/;
  return $line;
 }
 return $line;
}

#===============================================================================
sub replaceATMAddress
{
 my ( $line) = @_;
 if ($line =~ /47\.0091[0-9a-z\.]+/ ) {
  my $oldAtmAddr=$&;
  my $newAtmAddr="21.00ff.0000.ffff.0000.ffff.0000.ffff.0000.ffff.ff";
  $line =~ s/$oldAtmAddr/$newAtmAddr/;
 }
 return $line;
}

#===============================================================================
#gener descr
sub generText
{
 my $genText;
 for ( 0..5 ) {
  $genText.=chr(65+int(rand(25)));
  $genText.=chr(97+int(rand(25)));
 }
 return $genText;
}
