/**
 * @file
 * @brief util class definition
 * @author Miroslav Kubelik
 * @date 2006-2007
 */

#ifndef UTILS_H
#define UTILS_H

/* necessary declaration for this class and this templates definition */
#include <string>
#include <vector>
#include <algorithm>

/** function template - test if element is in vector */
template <typename T>
bool inVector(const T& elem,const std::vector<T>& v)
{
 /* ughhhh for this, see http://www.thescripts.com/forum/thread522881.html
 and http://www.comeaucomputing.com/tech...lates/#typename
 simple description
 vector<T>::const_iterator is assumed not to be a type here
 The language requires types that are dependent on the
 template variable to be called out with "typename"
 */
 typename std::vector<T>::const_iterator iter;

 iter = find(v.begin(), v.end(), elem);
 if ( iter  == v.end() ) return false;
 return true;
}

/**
 * Class for utility functions for manipulating with strings, regexp ...
 */
class Utils
{
 public:
  static int strtoint(std::string numbstr);
  static std::string inttostr(int num);
  static std::string upperCase(std::string& s);
  static std::string lowerCase(std::string& s);
  static bool regFirstMatch(std::string pattern, std::string text);
  static std::string trim(std::string& s,const std::string& drop = " ");
  static std::string ReadFile(const std::string& filename_i);
  static bool FileExist(std::string FileName);
  static bool inStringVector(const std::string& str, const std::vector<std::string>& vect);
  static void addQuotes(std::string& str);
  static std::vector<std::string> getDirFiles(std::string& dirname,bool filterDot=true);
  static void Tokenize(const std::string& str,std::vector<std::string>& tokens,const std::string& delimiters = " ");
  static float getUtilization(unsigned int wholeCount,unsigned int valCount);
};

#endif
