<?php
/**
 * Implementation of group controller actions. Groups are groups of devices,
 * device groups.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Serves device group controller actions.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class DevgroupController extends Zend_Controller_Action
{
//==============================================================================
/** Sets main menu into the "Groups" item.
 */
public function init()
{
 SiteTemplatePlugin::setMainMenu(SiteTemplatePlugin::MAINMENU_GROUPS);
}

//==============================================================================
/**
 * Action handler for index page. A view shows list of group with a pagination
 * if necessary.
 * @return void
 */
public function indexAction()
{
 //left block
 $this->view->leftBlocks = array(LeftBlock_SimpleSearch::getDevGroupSearch());

 //get current page number, default is 1
 $pageNo=$this->_hasParam(PageNav::NAVPARAM) ? $this->_getParam(PageNav::NAVPARAM) : 1;

 //group URL enumerator
 $groupUrlEnum=new DevgroupUrlEnum();
 //group object
 $group=new DeviceGroup();
 $groupCount=$group->getAllGroupsCount();
 
 //page navigator
 $pgNav=new PageNav($pageNo,$groupCount);
 $pgNav->MainUrl=$groupUrlEnum->index;

 //groups in the current page
 $this->view->groups=$group->getAllGroups($pageNo,$pgNav->getPerPageItems(),true);
 //all groups count
 $this->view->groupCount=$groupCount;
 //device url enumerator for a  view
 $this->view->groupUrlEnum=$groupUrlEnum;
 //add page navigator XHTML code for a view
 $this->view->pageNav=$pgNav->getNavXhtmlContent();
}

//==============================================================================
/**
 * Action handler for the detail view information about one group.
 * @return void
 */
public function viewAction()
{
 //object from the parameters
 $group=new DeviceGroup();
 $group->setDataByName($this->_getParam("group"));

 //device url enumerator
 $groupUrlEnum=DevgroupUrlEnum::factory($group);

 //infinite bidirectional itarator over all groups
 $iter = new BidirInfSimpleArrIterator($group->getAllGroups());
 //seek to current item
 $iter->seek($group);
 //next item
 $iter->next();$nextItem=$iter->current();
 $groupUrlEnum->setFromGroup($nextItem);
 $this->view->nextItem=$nextItem;
 $this->view->nextItemUrl=$groupUrlEnum->detail;
 //go to previous = twice back
 $iter->previous();$iter->previous();
 //previous
 $prevItem=$iter->current();
 $groupUrlEnum->setFromGroup($prevItem);
 $this->view->prevItem=$prevItem;
 $this->view->prevItemUrl=$groupUrlEnum->detail;

 //left block
 $this->view->leftBlocks = array(LeftBlock_SimpleSearch::getDevGroupSearch());

 //device properties for a view
 $this->view->groupName=$group->Name;
 $this->view->reportName=$group->ReportName;
 $this->view->reportCreateDate=$group->CreatedDT->format("r");
 $groupUrlEnum->setFromGroup($group);
 $this->view->groupUrlEnum=$groupUrlEnum;
 
 $membersCount=$group->getMembersCount();
 $this->view->membersCount=$membersCount;
 if ($membersCount) {
  //group members
  $this->view->groupMembers=$group->getMembers();
  //device url enumerator, which is used for device in a view interation
  $this->view->devUrlEnum=new DeviceUrlEnum();
 }
 //group summary
 $this->view->groupSummary=$group->Summary;
}

//==============================================================================
/**
 * Action handler for the search results, action serves request from the simple
 * search dialog and advanced search dialog if any exists.
 * @return void
 */
public function searchResultAction()
{
 //group instance
 $group=new DeviceGroup();
 //group url enumerator
 $groupUrlEnum=DevgroupUrlEnum::factory($group);

 //search object
 $search=Search::factorySearch("SearchDevGroup");
 //get current page number, default is 1
 $pageNo=$this->_hasParam(PageNav::NAVPARAM) ? $this->_getParam(PageNav::NAVPARAM) : 1;
 //set pagination in the search
 $search->setPageParams($pageNo,PageNav::PER_PAGE_COUNT);

 //if reguest is from simple search dialog ("simpleSearch" index is presented)
 //replace "searchText" index by "name" index
 if ( array_key_exists("simpleSearch",$params=Utils::getHTTPParams()) )
 {
  unset($params["simpleSearch"]);
  if (array_key_exists("searchText",$params)) {
   $params["name"]=$params["searchText"];
   unset($params["searchText"]);
  }
  //set search parameters
  $search->setParams($params);
 }

 //get searched items
 $items=&$search->searchItems();
 $itemsCount=$search->itemsCount();
 //save search params to session
 $search->saveToSession();

 //page navigator
 $pgNav=new PageNav($pageNo,$itemsCount);
 $pgNav->MainUrl=$groupUrlEnum->searchResult;

 //left block
 $this->view->leftBlocks = array(LeftBlock_SimpleSearch::getDevGroupSearch());

 //number of found groups
 $this->view->foundGroups=$itemsCount;
 //groups in the current page
 $this->view->groups=$items;
 //group url enumerator for a view
 $this->view->groupUrlEnum=$groupUrlEnum;
 //add page navigator XHTML code for a view
 $this->view->pageNav=$pgNav->getNavXhtmlContent();
}

//==============================================================================
/**
 * Action handler, which returns a picture with the timeslot summary for the current
 * device group.
 * Sets Img param in the response object as the file system path for the image.
 * This image is then returned as stream in the controller plugin {@link SiteTemplatePlugin}.
 * @return void
 */
public function tsSumImgAction()
{
 //object from the parameters
 $group=new DeviceGroup();
 $group->setDataByName($this->_getParam("group"));

 // Don't auto render
 $this->_helper->viewRenderer->setNoRender();
 $this->_setParam("Img",$group->SumPictures->getPathTimeslotPic());
 return;
}

//==============================================================================
/**
 * Action handler, which returns a picture with the e1 summary for the current
 * device group.
 * @see tsSumImgAction()
 * @return void
 */
public function e1SumImgAction()
{
 //object from the parameters
 $group=new DeviceGroup();
 $group->setDataByName($this->_getParam("group"));

 // Don't auto render
 $this->_helper->viewRenderer->setNoRender();
 $this->_setParam("Img",$group->SumPictures->getPathE1Pic());
 return;
}

#END CLASS
}
