<?php
/**
 * Implementation for the SiteTemplatePlugin class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Controller plugin for using a simple two step view or a sidewide template.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class SiteTemplatePlugin extends Zend_Controller_Plugin_Abstract
{
 // constants for a defining main menu items
 const MAINMENU_DEVICES="devices";
 const MAINMENU_GROUPS="groups";
 const MAINMENU_ABOUT="about";

 /** current main menu item identofier, one of MAINMENU constants
  * @var string
  */
 private static $_mainMenu;

//==============================================================================
/**
 * Setter for the $_mainMenu
 * @param string $menuId menu identifier
 * @throws InvalidArgumentException if $menuId isn't one of MAINMENU constants
 */
public static function setMainMenu($menuId)
{
 switch ($menuId) {
  case self::MAINMENU_DEVICES:
   self::$_mainMenu=self::MAINMENU_DEVICES;
   break;
  case self::MAINMENU_GROUPS:
   self::$_mainMenu=self::MAINMENU_GROUPS;
   break;
  case self::MAINMENU_ABOUT:
   self::$_mainMenu=self::MAINMENU_ABOUT;
   break;
  default:
   throw new InvalidArgumentException("unknow main menu identifier: $menuId");
   break;
 }
}

//==============================================================================
/**
 * Plugin hook after Zend_Controller_Front exits a whole dispatch loop.
 * 
 * We inject $response body to the sitewide template as the $content view variable
 * All view variables are persited because view is grabbed from the viewRenderer
 * plugin.
 *
 * We  can affect the entire layout of the page, and also chain together several
 * actions to build the final page.
 */
public function dispatchLoopShutdown()
{
 //assume that we've already determined the request is ajax
 $request  = $this->getRequest();
 $response = $this->getResponse();
 $viewRenderer = Zend_Controller_Action_HelperBroker::getExistingHelper('viewRenderer');
 $view = $viewRenderer->view;

 //ajax response
 if ($request->getParam('isAjax')) {
  //Ajax request detected
  //Get any variables set in the view
  $vars = get_object_vars($view);
  //Merge with named path segments in response
  $vars = array_merge($vars, $response->getBody(true));

  //Create a header and set the response body to a JSON value
  $response->setHeader('Content-Type', 'text/x-json');
  $response->setBody(Zend_Json::encode($vars));
  return;
 }

 //binary img response
 if (strlen($imgPath=$request->getParam('Img'))) {
  $imgContent = file_get_contents($imgPath);
  $response->setHeader("Content-type", "image/png");
  $response->setHeader("Content-length", strlen($imgContent));
  $response->setBody($imgContent);
  return;
 }

 //HTML response with sitewide template
 
 //left block
 if (is_array($view->leftBlocks)) {
  $view->leftPanel = $view->render("leftBlocksPart.phtml");
 }
 
 //Otherwise, process as normal page with two step view or sitewide template
 $view->content = $response->getBody();
 //set active main menu in a view
 $view->mainMenu = self::$_mainMenu;
 //there isn't necessary use scripth path for the template, because a view path is defined in
 //the viewRenderer as moduledirs/views via setViewBasePathSpec()
 $response->setBody($view->render("mainTemplate.phtml"));
}

//==============================================================================
/**
 * Gets a default left block, the block with links for devices and device groups
 * sections.
 *
 * @return array array with one or more LeftBlock objects, currently one left
 * block is supported.
 */
public static function getDefaultLeftParts()
{
 $block=new LeftBlock();
 $block->addUrl( array("Devices" => DeviceUrlEnum::factory()->index) );
 $block->addUrl( array("Groups" => DevgroupUrlEnum::factory()->index) );
 $block->title = "Main";

 return (array($block));
}


#END CLASS
}
