<?php
/**
* Implementation of utilities
*
* @package Library
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/

/**
* Utilities for help with XHTML forms, strings, etc..
* 
* @package Library
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/
class Utils {
//==============================================================================
/**
* Get parameters which was send to server from client as asoc. array, remove
* elements with same key as keys in filter array
*
* @param array $filter hash with filtered keys
* @return string XHTML page
*/
public static function getHTTPParamsFiltered($filter)
{
 $params=self::getHTTPParams();
 
 foreach($params as $key=>$val) {
  if (in_array($key,$filter)) continue;
  $newArr[$key]=$val; 
 }
 return isset($newArr) ? $newArr : null; 
}  

//==============================================================================
/**
* get parameters which was send to server from client as asoc. array
* @param array $filter hash with filtered keys 
* @return array parameters
*/
public static function getHTTPParams()
{
 $method=isset($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : "";
 
 switch ($method) {
  case "POST" :
   return $_POST;
   break;  
  case "GET" :
   return $_GET;
   break;
  default:
   throw new Exception(__METHOD__.": unknow HTTP request method"); 
  break;
 }
}

//==============================================================================
/**
* filter array elements by regular expression for key
*
* @param array $arr original array
* @return array filtered array
*/
public static function filterArrByKeyRegexp($arr,$pattern)
{
 $retarr=array();
 foreach($arr as $key => $val) {
  if (preg_match($pattern,$key)) {
   $retarr[$key]=$val;
  }
 }
 return $retarr;
}

//==============================================================================
/**
* Nice truncate the string.
*
* If a text length is beyond a certain $length and append with an ellipses or custom text
* @param string $str string to truncate
* @param int $length the number of characters allowed before truncating
* @param $append is appended to the truncated string
*/
public static function niceTruncate($str, $length = 40, $append = '&#8230;')
{
 return strlen($str) > $length ? trim(substr($str, 0, $length)) . $append : $str;
}

//==============================================================================
/**
* Remove all elements with concrete value from the array.
*
* Find the keys of the element with $elemVal value and remove it
* @param arrayref $arr reference to array, from that we want to remove
* @param mixed $elemVal a value for the removing entry
* @param bool strict strict check for comparsion
*/
public static function arrayRemove(array &$arr, $elemVal, $strict=false)
{
 $keys = array_keys($arr,$elemVal,$strict);
 foreach($keys as $sKey) {
  unset($arr[$sKey]);
 }
}

#END CLASS
}
