<?php
/**
 * Implementation of the summary base XML dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * summary base XML dao class
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class BaseSumXMLDao
{
 /**
  * XML for the base summary section as the data source.
  *
  * @var SimpleXMLElement
  */
 private $_xmlObject=null;

//==============================================================================
/**
 * inits data source
 * @param SimpleXMLElement $baseSumXML XML element for the base summary
 */
public function __construct(SimpleXMLElement $baseSumXML)
{
 $this->_xmlObject = $baseSumXML;
}

//==============================================================================
/**
 * Gets transfer object
 * @return BaseSumTO
 */
public function getBaseSum()
{
 return self::_getTO($this->_xmlObject);
}

//==============================================================================
/**
 * Builds a corresponding Transfer Object from the base summary part XML element.
 * @param SimpleXMLElement $basePartXML the base summary part XML element
 * @return BaseSumTO
 */
private static function _getTO(SimpleXMLElement $baseSumXML)
{
 $ourTO=new BaseSumTO;
 $ourTO->summary=(int)$baseSumXML->summary;
 $ourTO->used=(int)$baseSumXML->used;
 $ourTO->free=(int)$baseSumXML->free;
 $ourTO->utilization=(float)$baseSumXML->utilization;

 return $ourTO;
}

#END CLASS
}
