<?php
/**
 * Implementation of the Class for the group of timeslots.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Class for the group of timeslots in E1 - business (domain) class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class ChannelGroup extends Model
{
 /**
  * id
  * @var int
  */
 private $_id;

 /**
  * timeslots range (examples: "1-16" , "unframed", "1-16,24,25-31")
  * @var string
  */
 private $_tsRange;

 /**
  * the serial interface identifier for a serial interface which is bound with
  * a channel group
  * @var string
  */
 private $_serialIfId;

 /**
  * description
  * In cisco device configuration, this description is on the bound serail interface
  * @var string
  */
 private $_descr;

 /**
  * ip address
  * In cisco device configuration, this ip address is on the bound serail interface
  * @var string
  */
 private $_ipAddr;


//==============================================================================
public function setDaoByChannelGroupsXml(SimpleXMLelement $channelGroupsXml)
{
 $this->_dao=new ChannelGroupXMLDao( $channelGroupsXml );
}

//==============================================================================
/** inherited property getter
* @param string $property property identifier
*
* <b>Defined properties</b>
* <ul>
*   <li>string Id - get - {@link $_id}</li>
*   <li>string TsRange - get - {@link $_tsRange}</li>
* </ul>
*
* @throws Exception if $property parameter is an undefined property identifier
* @return mixed $property value
*/
public function __get($property)
{
 switch ($property) {
  case "Id":
   return $this->_id;
   break;
  case "TsRange":
   return $this->_tsRange;
   break;
  case "IpAddr":
   return $this->_ipAddr;
   break;
  case "Description":
   return $this->_descr;
   break;
  default:
   return parent::__get($property);
   break;
 }
}

//==============================================================================
/**
 * Checks if channel group is unframed or not
 * @return bool
 */
public function isUnframed()
{
 return $this->_tsRange=="unframed" ? true : false;
}

//==============================================================================
/**
 * Sets properties from the transfer object
 * @param ChannelGroupTO $chanGrTO transfer object
 */
private function _setFromTO(ChannelGroupTO $chanGrTO)
{
 $this->_id=$chanGrTO->id;
 $this->_tsRange=$chanGrTO->tsRange;
 $this->_serialIfId=$chanGrTO->serialIfId;
 $this->_descr=$chanGrTO->descr;
 $this->_ipAddr=$chanGrTO->ipAddr;
}

//==============================================================================
/**
 * Gets all channel groups.
 * @param bool $returnTO has same sence as in the {@link CiscoDevice::getAllDevices()}
 * @return array array of the self or ChannelGroupTO objects
 */
public function &getAllChannelGroups($returnTO=false)
{
 $retArr=array();

 $allItems=&$this->_dao->getAllChannelGroups();
 if(count($allItems)==0) return $retArr;

 if ($returnTO) return $allItems;

 foreach($allItems as $chanGrpTO) {
  $item=new self;
  $item->_setFromTO($chanGrpTO);
  $retArr[]=$item;
 }

 return $retArr;
}

#END CLASS
}
