<?php
/**
 * Implementation of the channel group XML dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * channel group XML dao class
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class ChannelGroupXMLDao
{
 /**
  * XML for the channel groups section as the data source
  * @var SimpleXMLElement
  */
 private $_xmlObject=null;

//==============================================================================
/**
 * inits data source
 * @param SimpleXMLElement $channelGroupsXML XML element for the channel group
 */
public function __construct(SimpleXMLElement $channelGroupsXML)
{
 $this->_xmlObject = $channelGroupsXML;
}

//==============================================================================
/**
 * Builds a corresponding Transfer Object from the channel group XML element. from
 * @param SimpleXMLElement $channelGrpElem channel group XML element
 * @return ChannelGroupTO
 */
private static function _getTO(SimpleXMLElement $channelGrpElem)
{
 $ourTO=new ChannelGroupTO();

 foreach ($channelGrpElem->attributes() as $attrName => $value) {
  switch ((string)$attrName) {
   case "id":
    $ourTO->id=(string)$value;
    break;
   case "ts":
    $ourTO->tsRange=(string)$value;
    break;
   default:
 	  break;
  }
 }

 $ourTO->serialIfId=trim( (string)$channelGrpElem->serailid );
 $ourTO->descr=trim( (string)$channelGrpElem->descr );
 $ourTO->ipAddr=trim( (string)$channelGrpElem->ipaddr );

 return $ourTO;
}

//==============================================================================
/**
 * Gets all channel groups.
 * @return array array of the ChannelGroupTO objects
 */
public function &getAllChannelGroups()
{
 $retArr=array();
 foreach($this->_xmlObject as $chanGrpNode) {
  $retArr[]=$this->_getTO($chanGrpNode);
 }
 return $retArr;
}

#END CLASS
}
