<?php
/**
* Implementation of the device controller class
*
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/

/**
* Abstract class for the generic controller on the network device.
*
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/
class DeviceContr extends Model
{
 /**
  * controller name e.g. 1/0
  * @var string
  */
 protected $_name;

 /**
  * controller description
  * @var string
  */
 protected $_descr;

//==============================================================================
/** inherited property getter
* @param string $property property identifier
*
* <b>Defined properties</b>
* <ul>
*   <li>string Name - get/set - {@link name}</li>
*   <li>string Description - get/set - {@link description}</li>
* </ul>
*
* @throws Exception if $property parameter is an undefined property identifier
* @return mixed $property value
*/
public function __get($property)
{
 switch ($property) {
  case "Name":
   return $this->_name;
   break;
  case "Description":
   return $this->_descr;
   break;
  default:
   return parent::__get($property);
   break;
 }
}

//==============================================================================
/** inherited property setter
*
* For the properties definition, see {@link __get()}.
*
* @param string $property property identifier
* @param mixed $val property value
*
* @throws InvalidArgumentException if $property parameter is the undefined property identifier
*  or if $val is bad value for $property
*/
public function __set($property,$val)
{
 switch ($property) {
  case "Name":
   $this->_name=$val;
   break;
  case "Description":
   $this->_descr=$val;
   break;
  default:
   parent::__set($property);
   break;
 }
}

//==============================================================================
protected function _setFromTO(DeviceContrTO $contrTO)
{
 $this->_name=$contrTO->name;
 $this->_descr=$contrTO->description;
}

//==============================================================================
/**
 * Gets all controllers.
 * @param bool $returnTO has same sence as in the {@link CiscoDevice::getAllDevices()}
 * @param bool $copyDaoRef copy Dao reference from current object to all controllers
 * in the array
 * @return array array of the self or DeviceContrTO objects
 */
public function &getAllControllers($returnTO=false,$copyDaoRef=true)
{
 $retArr=array();

 $allItems=&$this->_dao->getAllControllers();
 if(count($allItems)==0) return $retArr;

 if ($returnTO) return $allItems;

 foreach($allItems as $contrTO) {
  //determine class dynamically
  $currentClass=get_class($this);
  $item=new $currentClass;
  //copy dao reference if necessary necessary
  if ($copyDaoRef) $item->_dao=$this->_dao;
  $item->_setFromTO($contrTO);
  $retArr[]=$item;
 }
 
 return $retArr;
}

#END CLASS
}
