<?php
/**
 * Implementation of the device controller XML dao class
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Device controller XML dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
abstract class DeviceContrXMLDao
{
 /**
  * Data soutce element for the controllers section.
  * Controllers section can be:
  * <ul>
  *  <li>E1Controllers->controller for all E1 controllers<li>
  *  <li>E3Controllers->E3Controller for all E3 controllers<li>
  *  <li>E3Controller->controller for all sub E1 in one E3 controller<li>
  * </ul>
  *
  * @var SimpleXMLElement
  */
 protected $_xmlObject=null;

//==============================================================================
/**
 * inits data source from the XML element
 * @param SimpleXMLElement $controllersXML xml element for all controllers
 * section
 */
public function __construct(SimpleXMLElement $controllersXML)
{
 $this->_xmlObject=$controllersXML;
}

//==============================================================================
/**
 * Returns the XML element for the specific controller.
 * @param string $nodeId controller identificator
 * @return SimpleXMLElement
 */
public function getControllerXML($nodeId)
{
 if (empty($nodeId))
  throw new Exception("node id must be set!");

 foreach($this->_xmlObject as $contrNode) {
  if ((string)$contrNode["id"] == $nodeId)
   return $contrNode;
 }
 throw new Exception("XML node for the controller ". $nodeId . "doesn't exist");
}

//==============================================================================
/**
 * Not yet implemented.
 */
public function getControllerByName($nodeId)
{
 throw new Exception("No implementation");
}

//==============================================================================
/**
 * Creates and returns controller transfer object.
 * @return DeviceContrTO
 */
protected function _createTO()
{
 return new DeviceContrTO();
}

//==============================================================================
/**
 * build a corresponding Transfer Object from the XML element
 * @return DeviceContrTO
 */
protected function _getTO(SimpleXMLElement $contrElement)
{
 $ourTO=$this->_createTO();

 foreach ($contrElement->attributes() as $attrName => $value)
  $this->_setTOproperty($ourTO,(string)$attrName,(string)$value);

 return $ourTO;
}

//==============================================================================
/**
 * Sets the property for the transfer object.
 * @param DeviceContrTO $transferObject transfer object for the controller
 * @param string $attrName property name identifier
 * @param mixed $value the property value
 */
protected function _setTOproperty(DeviceContrTO $transferObject,$attrName,$value)
{
  switch ($attrName) {
   case "id":
    $transferObject->name=$value;
    break;
   case "description":
    $transferObject->description=$value;
    break;
   default:
    throw new Exception("cannot ". get_class($transferObject) . " property for an attribute"
     . $attrName . ", attribute is not allowed");
    break;
  }
}

//==============================================================================
/**
 * Gets all controllers.
 * @return array array of the DeviceContrTO objects
 */
public function &getAllControllers()
{
 $retArr=array();
 foreach($this->_xmlObject as $contrNode) {
  $retArr[]=$this->_getTO($contrNode);
 }
 return $retArr;
}

#END CLASS
}
