<?php
/**
* Implementation of the E1 device controller class
*
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/

/**
* class for the E1 device controller
*
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/
class E1Contr extends DeviceContr
{
 /**
  * E1 controller clock type e.g. internal, line ...
  * @var string
  */
 private $_clock;

 /**
  * E1 controller CRC framing
  * @var string
  */
 private $_framing;
 
//==============================================================================
public function setDaoByControllersXML(SimpleXMLelement $controllersXML)
{
 $this->_dao=new E1ContrXMLDao($controllersXML);
}

//==============================================================================
/** inherited property getter
* @param string $property property identifier
*
* <b>Defined properties</b>
* <ul>
*   <li>string Clock - get/set - {@link clock}</li>
*   <li>string Framing - get/set - {@link framing}</li>
* </ul>
*
* @throws Exception if $property parameter is an undefined property identifier
* @return mixed $property value
*/
public function __get($property)
{
 switch ($property) {
  case "Clock":
   return $this->_clock;
   break;
  case "Framing":
   return $this->_framing;
   break;
  default:
   return parent::__get($property);
 	 break;
 }
}

//==============================================================================
/** inherited property setter
*
* For the properties definition, see {@link __get()}.
*
* @param string $property property identifier
* @param mixed $val property value
*
* @throws InvalidArgumentException if $property parameter is the undefined property identifier
*  or if $val is bad value for $property
*/
public function __set($property,$val)
{
 switch ($property) {
  case "Clock":
   $this->_clock=$val;
   break;
  case "Framing":
   $this->_framing=$val;
 	 break;
  default:
   parent::__set($property);
 	 break;
 }
}

//==============================================================================
protected function _setFromTO(DeviceContrTO $contrTO)
{
 parent::_setFromTO($contrTO);
 $this->_clock=$contrTO->clock;
 $this->_framing=$contrTO->framing;
}

//==============================================================================
public function setDataByName($name)
{
 $this->_setFromTO( $this->_dao->getControllerByName($name) );
}

//==============================================================================
public function getAllChannelGroupsCount()
{
 return $this->_dao->getAllChannelGroupsCount($this->_name);
}

//==============================================================================
/**
 * Get all channel groups for current E1 controller.
 * @return array array of the ChannelGroup objects
 */
public function &getAllChannelGroups()
{
 $channelGr=new ChannelGroup();
 $channelGr->setDaoByChannelGroupsXml( E1ContrXMLDao::getChannelGroupsXML($this->_dao->getControllerXML($this->_name)) );
 return $channelGr->getAllChannelGroups();
}

#END CLASS
}
