<?php
/**
 * Implementation of the E1 controller XML dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * E1 controller XML dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class E1ContrXMLDao extends DeviceContrXMLDao
{
//==============================================================================
/**
 * Creates and returns E1 controller transfer object.
 * @return E1ContrTO
 */
protected function _createTO()
{
 return new E1ContrTO();
}

//==============================================================================
/**
 * Gets all channel groups count for E1 controller.
 * @param int $controllerId E1 controller Id
 * @return int
 */
public function getAllChannelGroupsCount($controllerId)
{
 return count( self::getChannelGroupsXML($this->getControllerXML($controllerId)) );
}

//==============================================================================
/**
 * Gets all XML channel group elements from the XML e1 controller element.
 * @param SimpleXMLElement $e1ContrXML the e1 controller XML element
 * @return SimpleXMLElement
 */
public static function getChannelGroupsXML(SimpleXMLElement $e1ContrXML)
{
 return $e1ContrXML->channelgrps->channelgrp;
}

//==============================================================================
/**
 * Sets the property for the E1 controller transfer object.
 * @param E1ContrTO $transferObject transfer object for the E1 controller
 * @param string $attrName property name identifier
 * @param mixed $value the property value
 */
protected function _setTOproperty(DeviceContrTO $transferObject,$attrName,$value)
{
 switch ($attrName) {
   case "clock":
    $transferObject->clock=$value;
    break;
   case "framing":
    $transferObject->framing=$value;
    break;
   default:
    parent::_setTOproperty($transferObject,$attrName,$value);
   break;
 }
}

#END CLASS
}
