<?php
/**
* Implementation of the base class for all models (in the MVC pattern sense)
*
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/

/**
* Base class for all models (in the MVC pattern sense)
*
* Class implemenst a basic property get/set mechanism via magic methods __get and __set
* with an exception handling.
* 
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/
abstract class Model
{
 /**
  * data access object
  * @var object
  */
 protected $_dao = null;

//==============================================================================
/** base universal inherited property getter
*
* Always throw the Exception, because this class has no properties.
* @param string $property property identifier
* @throws InvalidArgumentException if $property parameter is the undefined property identifier
* @return mixed $property value
*/
public function __get($property)
{
 throw new InvalidArgumentException("try to get undefined property $property for the class ".get_class($this));
}

//==============================================================================
/**
 * Gets reference to the copy of the current dao
 * @return object
 */
public function getDaoCopy()
{
 $dao = clone $this->_dao;
 return $dao;
}

//==============================================================================
/** base universal inherited property setter
*
* Always throw the Exception, because this class has no properties
*
* @param string $property property identifier
* @param mixed $val property value
* @throws InvalidArgumentException if $property parameter is the undefined property identifier
* or $val has a bad format or a type
*/
public function __set($property,$val)
{
 throw new InvalidArgumentException ("try to set undefined property $property or bad value "
                      . "for this property in the class ".get_class($this)
                      . (empty($valOut) ? "" : ("\n value dump: ".$valOut))
                     );
}

#END CLASS
}
