<?php
/**
 * An implementation of the search for the devices.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Search class for the devices
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2006-2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class Search_Device extends Search
{
//==============================================================================
/**
 * Just calls parent constructor.
 */
protected function __construct()
{
 parent::__construct(null);
}

//==============================================================================
/**
 * Search items.
 * @return arrayref reference to array with CiscoDeviceTO objects
 * @throws RuntimeException which bubbles from {@link _matched}
 */
public function &searchItems()
{
 $dev=new CiscoDevice();
 //get Transfer objects, not bussines objects
 $allItems=&$dev->getAllDevices(null,null,true);

 $found=array();
 foreach($allItems as $item) {
  if ($this->_matched($item)) $found[]=$item;
 }

 $this->_foundCount=count($found);

 //if the pagination presents, slice array
 if ($this->_paging) $found=array_slice($found,($this->_pageNumber-1)*$this->_perPageItems,$this->_perPageItems);

 return $found;
}

//=============================================================================
/**
 * Checks if item matches current search parameters.
 * @return bool true if mathed false otherwise
 * @param CiscoDeviceTO $item item, which we want match
 * @throws RuntimeException if we want match against undefined parametr
 */
private function _matched(CiscoDeviceTO $item)
{
 $result=false;
 
 foreach(array_keys($this->_searchParams) as $key) {
  switch ($key) {
   case "id":
    if (preg_match("/".$this->_searchParams[$key]."/",$item->id)) {
     $result=true;
    }
    else
     $result=false;
    break;
   default:
    throw new RuntimeException("unknow search parameter: $key");
  }
 }

 return $result;
}

#END CLASS
}
