<?php
/**
 * Implementation of the class for the summary pictures.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Class for the summary pictures. Pictures has been generated from the RRD files.
 * Currently E1 and timeslots summaries pictures are used.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class SumPics
{
 /** file extension */
 const EXT="png";

 /** suffix for the e1 summary image */
 const E1_ID="e1";
 /** suffix for the timeslot summary image */
 const TS_ID="ts";

 /** directory with pictures
  * @var string
  */
 private $_dir;

 /** First part of the picture name.
  * It is derived from the device or group.
  * @var string
  */
 private $_prefix;

//==============================================================================
/**
 * Sets $_prefix and $_dir
 * @param string $dir see {@link $_dir}
 * @param string $prefix see {@link $_prefix}
 */
public function __construct($dir,$prefix)
{
 $this->_dir=$dir;
 $this->_prefix=$prefix;
}

//==============================================================================
/**
 * Gets filesystem path for the E1 summary picture.
 * @return string
 */
public function getPathE1Pic()
{
 return $this->_getPatchPic(self::E1_ID);
}

//==============================================================================
/**
 * Gets filesystem path for the timeslot summary picture.
 * @return string
 */
public function getPathTimeslotPic()
{
 return $this->_getPatchPic(self::TS_ID);
}

//==============================================================================
/**
 * Gets filesystem path for some kind of picture.
 * Currently E1 or timeslots pictures.
 * @param string $typeId type of picture one of class constants.
 * @return string
 */
private function _getPatchPic($typeId)
{
 return $this->_dir . DIRECTORY_SEPARATOR . $this->_prefix . $typeId
  . "." . self::EXT;
}

#END CLASS
}
