<?php
/**
 * Implementation of the summary class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Summary class - Business (domain) class. This class is used as the summary
 * for groups and for devices. It corresponds with content of <summary> tag.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class SyncSum extends Model
{
 /** E1 Summary
  * @var SyncSumPart
  */
 private $_e1Sum=null;
 
 /** E3 Summary
  * @var SyncSumPart
  */
 private $_e3Sum=null;

 /** sonet summary
  * @var SyncSumPart
  */
 private $_sonetSum=null;

 /** whole summary for all synchronous technology: E1,E3,STM-1
  * @var SyncSumPart
  */
 private $_wholeSyncSum=null;

//==============================================================================
/** inherited property getter
 * @param string $property property identifier
 *
 * <b>Defined properties</b>
 * <ul>
 *  <li>SyncSumPart E1Summary - get - {@link $_e1Sum}</li>
 *  <li>SyncSumPart E3Summary - get - {@link $_e3Sum}</li>
 *  <li>SyncSumPart SonetSummary - get - {@link $_sonetSum}</li>
 *  <li>SyncSumPart WholeSyncSummary - get - {@link $_wholeSyncSum}</li>
 * </ul>
 *
 * @throws Exception if $property parameter is an undefined property identifier
 * @return mixed $property value
*/
public function __get($property)
{
 switch ($property) {
  case "E1Summary":
   return $this->_getE1Summary();
   break;
  case "E3Summary":
   return $this->_getE3Summary();
   break;
  case "SonetSummary":
   return $this->_getSonetSummary();
   break;
  case "WholeSyncSummary":
   return $this->_getWholeSyncSummary();
   break;
  default:
   return parent::__get($property);
 	 break;
 }
}

//==============================================================================
/**
 * Set Dao member variable.
 * @param SimpleXMLelement $summaryXml summary XML element
 */
public function setDaoBySummaryXml(SimpleXMLelement $summaryXml)
{
 $this->_dao=new SyncSumXMLDao($summaryXml);
}

//==============================================================================
/**
 * Returns summary for E1s, a private accessor for $_e1Sum.
 * @return SyncSumPart
 */
private function _getE1Summary()
{
 if (is_null($this->_e1Sum)) {
  $this->_e1Sum=new SyncSumPart();
  $this->_e1Sum->setDaoBySummaryXml(SyncSumXMLDao::getE1SumPartXML($this->_dao->getSummaryXML()));
  $this->_e1Sum->setData();
 }
 
 return $this->_e1Sum;
}

//==============================================================================
/**
 * Returns summary for E3s, a private accessor for $_e3Sum.
 * @return SyncSumPart
 */
private function _getE3Summary()
{
 if (is_null($this->_e3Sum)) {
  $this->_e3Sum=new SyncSumPart();
  $this->_e3Sum->setDaoBySummaryXml(SyncSumXMLDao::getE3SumPartXML($this->_dao->getSummaryXML()));
  $this->_e3Sum->setData();
 }

 return $this->_e3Sum;
}

//==============================================================================
/**
 * Returns summary for sonets, a private accessor for $_sonetSum.
 * @return SyncSumPart
 */
private function _getSonetSummary()
{
 if (is_null($this->_sonetSum)) {
  $this->_sonetSum=new SyncSumPart();
  $this->_sonetSum->setDaoBySummaryXml(SyncSumXMLDao::getSonetSumPartXML($this->_dao->getSummaryXML()));
  $this->_sonetSum->setData();
 }

 return $this->_sonetSum;
}

//==============================================================================
/**
 * Returns summary for whole synchronous technology, a private accessor for $_wholeSyncSum.
 * @return SyncSumPart
 */
private function _getWholeSyncSummary()
{
 if (is_null($this->_wholeSyncSum)) {
  $this->_wholeSyncSum=new SyncSumPart();
  $this->_wholeSyncSum->setDaoBySummaryXml(SyncSumXMLDao::getWholeSyncSumPartXML($this->_dao->getSummaryXML()));
  $this->_wholeSyncSum->setData();
 }

 return $this->_wholeSyncSum;
}

#END CLASS
}
