<?php
/**
 * Implementation of the class for one summary part for synchronous summary.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Synchronous summary part - Business (domain) class.
 * This class encapsulates one synchronous summary, timeslost's cout, E1's count etc. Can be used
 * for all e1 summary, all Sonet summary etc.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class SyncSumPart extends Model
{
 /** a summary for timeslots
  * @var BaseSum
  */
 private $_timeslotsSum=null;
 
 /** a summary for E1s
  * @var BaseSum
  */
 private $_e1Sum=null;

 /** a number of channel groups
  * @var int
  */
 private $_channelGroups;

//==============================================================================
/** inherited property getter
 * @param string $property property identifier
 *
 * <b>Defined properties</b>
 * <ul>
 *   <li>int ChannelGroups - get - {@link $_channelGroups}</li>
 *   <li>string IpAddr - get/set - {@link $_ipAddr}</li>
 *   <li>BaseSum TimeslotsSum - get - {@link _getTimeslotsSum()}</li>
 *   <li>BaseSum E1sSum - get - {@link _getE1sSum()}</li>
 * </ul>
 *
 * @throws Exception if $property parameter is an undefined property identifier
 * @return mixed $property value
 */
public function __get($property)
{
 switch ($property) {
  case "ChannelGroups":
   return $this->_channelGroups;
   break;
  case "TimeslotsSum":
   return $this->_getTimeslotsSum();
   break;
  case "E1sSum":
   return $this->_getE1sSum();
   break;
  default:
   return parent::__get($property);
 	 break;
 }
}

//==============================================================================
/**
 * Set dao property by XML for summary part.
 * e.g. <SONETsummary> tag
 * @param SimpleXMLelement $sumPartXml XML for one summary part element.
 */
public function setDaoBySummaryXml(SimpleXMLelement $sumPartXml)
{
 $this->_dao=new SyncSumPartXMLDao($sumPartXml);
}

//==============================================================================
/**
 * Sets properties from the transfer object
 * @param SyncSumPartTO $sumPartTO transfer object
 */
private function _setFromTO(SyncSumPartTO $sumPartTO)
{
 $this->_channelGroups=$sumPartTO->channelGroups;
}

//==============================================================================
/**
 * Init properties from dao.
 */
public function setData()
{
 $this->_setFromTO( $this->_dao->getSyncSumPart() );
}

//==============================================================================
/**
 * Returns summary for timeslots, a private accessor for $_timeslotsSum.
 * @return BaseSum
 */
private function _getTimeslotsSum()
{
 if (is_null($this->_timeslotsSum)) {
  $this->_timeslotsSum=new BaseSum();
  $this->_timeslotsSum->setDaoByBaseSummaryXml(SyncSumPartXMLDao::getTimeslotsXML($this->_dao->getSummaryPartXML()));
  $this->_timeslotsSum->setData();
 }

 return $this->_timeslotsSum;
}

//==============================================================================
/**
 * Returns summary for E1s, a private accessor for $_e1Sum.
 * @return BaseSum
 */
private function _getE1sSum()
{
 if (is_null($this->_e1Sum)) {
  $this->_e1Sum=new BaseSum();
  $this->_e1Sum->setDaoByBaseSummaryXml(SyncSumPartXMLDao::getE1sXML($this->_dao->getSummaryPartXML()));
  $this->_e1Sum->setData();
 }

 return $this->_e1Sum;
}

#END CLASS
}
