<?php
/**
 * Implementation of the summary part XML dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * XML Dao class for one summary part for synchronous summary.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

class SyncSumPartXMLDao
{
 /**
  * XML for the summary part section.
  *
  * @var SimpleXMLElement
  */
 private $_xmlObject=null;

//==============================================================================
/**
 * Sets XML object as data source.
 * @param SimpleXMLElement $summaryPartXML XML for one summary part element
 */
public function __construct(SimpleXMLElement $summaryPartXML)
{
 $this->_xmlObject=$summaryPartXML;
}

//==============================================================================
/**
 * Gets XML data source object.
 * @return SimpleXMLElement
 */
public function getSummaryPartXML()
{
 return $this->_xmlObject;
}

//==============================================================================
/**
 * Gets XML object for timeslots summary.
 * @param SimpleXMLElement $summaryPartXML summary part XML element
 * @return SimpleXMLElement XML <timeslosts> element
 */
public static function getTimeslotsXML(SimpleXMLElement $summaryPartXML)
{
 return $summaryPartXML->timeslosts;
}

//==============================================================================
/**
 * Gets XML object for E1s summary.
 * @param SimpleXMLElement $summaryPartXML summary part XML element
 * @return SimpleXMLElement XML <E1s> element
 */
public static function getE1sXML(SimpleXMLElement $summaryPartXML)
{
 return $summaryPartXML->E1s;
}

//==============================================================================
/**
 * Gets transfer object
 * @return SyncSumPartTO
 */
public function getSyncSumPart()
{
 return self::_getTO($this->_xmlObject);
}

//==============================================================================
/**
 * Builds a corresponding Transfer Object from the summary part XML element.
 * @param SimpleXMLElement $summaryPartXML the summary part XML element
 * @return SyncSumPartTO
 */
private static function _getTO(SimpleXMLElement $summaryPartXML)
{
 $ourTO=new SyncSumPartTO;
 $ourTO->channelGroups=(int)$summaryPartXML->channelgroups;
 return $ourTO;
}

#END CLASS
}
