<?php
/**
 * Implementation of the synchronous summary XML Dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Synchronous summary XML Dao class.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class SyncSumXMLDao
{
 /**
  * XML for the summary section as the data source
  * @var SimpleXMLElement
  */
 private $_xmlObject=null;

//==============================================================================
/**
 * Sets XML object as data source.
 * @param SimpleXMLElement $summaryPartXML XML for summary part element <summary>
 */
public function __construct(SimpleXMLElement $summaryXML)
{
 $this->_xmlObject = $summaryXML;
}

//==============================================================================
/**
 * Gets XML data source object.
 * @return SimpleXMLElement
 */
public function getSummaryXML()
{
 return $this->_xmlObject;
}

//==============================================================================
/**
 * Gets XML object for E1 summary.
 * @param SimpleXMLElement $summaryXML XML <summary> element
 * @return SimpleXMLElement XML <E1summary> element
 */
public static function getE1SumPartXML(SimpleXMLElement $summaryXML)
{
 return $summaryXML->E1summary;
}

//==============================================================================
/**
 * Gets XML object for E3 summary.
 * @param SimpleXMLElement $summaryXML XML <summary> element
 * @return SimpleXMLElement XML <E3summary> element
 */
public static function getE3SumPartXML(SimpleXMLElement $summaryXML)
{
 return $summaryXML->E3summary;
}

//==============================================================================
/**
 * Gets XML object for Sonet summary.
 * @param SimpleXMLElement $summaryXML XML <summary> element
 * @return SimpleXMLElement XML <SONETsummary> element
 */
public static function getSonetSumPartXML(SimpleXMLElement $summaryXML)
{
 return $summaryXML->SONETsummary;
}

//==============================================================================
/**
 * Gets XML object for whole synchronous summary.
 * @param SimpleXMLElement $summaryXML XML <summary> element
 * @return SimpleXMLElement XML <Syncsummary> element
 */
public static function getWholeSyncSumPartXML(SimpleXMLElement $summaryXML)
{
 return $summaryXML->Syncsummary;
}

#END CLASS
}
