<?php
/**
 * The implementation of the URL Enumerator for group of devices controller URLs
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * URL enumerator for group of devices controller URLs
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class DevgroupUrlEnum extends UrlEasyGet
{
 /**
  * grooup name
  * @var string
  */
 private $_name;

//==============================================================================
/**
 * create empty enumerator
 */
public function __construct()
{
 $config=Zend_Registry::get("conf");
 //constructor with XML file from controller directory
 parent::__construct($config->controllerDir
  . DIRECTORY_SEPARATOR . "DevgroupControllerMap.xml");
}

//==============================================================================
/**
 * Sets properties from the group object.
 * @param DeviceGroup $group a group from which will be enumerator properties set
 */
public function setFromGroup(DeviceGroup $group)
{
 $this->_name=$group->Name;
}

//==============================================================================
/**
 * Sets properties from the group transfer object.
 * @param DeviceGroupTO $group group from which will be enumerator properties set
 */
public function setFromGroupTO(DeviceGroupTO $group)
{
 $this->_name=$group->name;
}

//==============================================================================
/**
 * Factory method, usefull for calling in views, like the helper.
 * @param object $from object from which will be enumerator properties set can be:
 * - DeviceGroup
 * - DeviceGroupTO
 * @return object DevgroupUrlEnum
 * @throws Exception when we want create object from unknow object typ, see the $from
 * parametr description
 */
public static function factory($from=null)
{
 $obj=new self;

 if (is_null($from)) {
  return $obj;
 } elseif ($from instanceof DeviceGroup) {
  $obj->setFromGroup($from);
 } elseif ($from instanceof DeviceGroupTO) {
  $obj->setFromGroupTO($from);
 } else {
  throw new Exception ("cannot set device url enumerator from "
  . get_class($from) . "object" );
 }
 
 return $obj;
}

//==============================================================================
/**
 * Main function, return URL which is defined by urlName in the XML file.
 * @param string $urlName
 * @return string
 */
public function __get($urlName)
{
 //get URL defined by the map
 $url=parent::__get($urlName);
 //replace URL parameters
 $this->replaceParams($url);

 //add baseUrl and return
 return (AppBaseUrl::getBaseUrl().$url);
}

//==============================================================================
/**
 * Replace parameters in the URL, parameters are in XML file strings beginning with
 * colon (e.g :param).
 * @param stringRef $url url which will be worked up
 */
private function replaceParams(&$url)
{
 /* NOTE for strpos, use always strong non equivalence !== not just !=, see
    manual for strpos
 */
 if (strpos($url,":group") !== false ) {
  $url = str_replace(":group", $this->_name,$url);
 }
}

#END CLASS
}
