<?php
/**
* The implementation of the URL Enumerator for device controller URLs
*
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/

/**
* URL enumerator for device controller URLs
*
* @package ndevinfo
* @author Miroslav Kubelik (koubel@volny.cz)
* @copyright Copyright (c) 2007 Miroslav Kubelik
* @license http://opensource.org/licenses/gpl-license.php GNU GPL
*/
class DeviceUrlEnum extends UrlEasyGet
{
 /**
  * device identifier
  * @var int
  */
 private $_devId;

//==============================================================================
/**
 * create empty enumerator
 */
public function __construct()
{
 $config=Zend_Registry::get("conf");
 //constructor with XML file from controller directory
 parent::__construct($config->controllerDir
  . DIRECTORY_SEPARATOR . "DeviceControllerMap.xml");
}

//==============================================================================
/**
 * Sets properties from the device object.
 * @param CiscoDevice $dev device from which will be enumerator properties set
 */
public function setFromDevice(CiscoDevice $dev)
{
 $this->_devId=$dev->Id;
}

//==============================================================================
/**
 * Sets properties from the device transfer object.
 * @param CiscoDeviceTO $dev device from which will be enumerator properties set
 */
public function setFromDeviceTO(CiscoDeviceTO $dev)
{
 $this->_devId=$dev->id;
}

//==============================================================================
/**
 * Factory method, usefull for calling in views, like the helper.
 * @param object $from object from which will be enumerator properties set can be:
 * - CiscoDevice
 * - CiscoDeviceTO
 * @return object DeviceUrlEnum
 * @throws Exception when we want create object from unknow object typ, see the $from
 * parametr description
 */
public static function factory($from=null)
{
 $obj=new self;

 if (is_null($from)) {
  return $obj;
 } elseif ($from instanceof CiscoDevice) {
  $obj->setFromDevice($from);
 } elseif ($from instanceof CiscoDeviceTO) {
  $obj->setFromDeviceTO($from);
 } else {
  throw new Exception ("cannot set device url enumerator from "
  . get_class($from) . "object" );
 }
 
 return $obj;
}

//==============================================================================
/**
 * Main function, return URL which is defined by urlName in the XML file.
 * @param string $urlName
 * @return string
 */
public function __get($urlName)
{
 //get URL defined by the map
 $url=parent::__get($urlName);
 //replace URL parameters
 $this->replaceParams($url);

 //add baseUrl and return
 return (AppBaseUrl::getBaseUrl().$url);
}

//==============================================================================
/**
 * Replace parameters in the URL, parameters are in XML file strings beginning with
 * colon (e.g :param).
 * @param stringRef $url url which will be worked up
 */
private function replaceParams(&$url)
{
 /* NOTE for strpos, use always strong non equivalence !== not just !=, see
    manual for strpos
 */
 if (strpos($url,":device") !== false ) {
  $url = str_replace(":device", $this->_devId,$url);
 }
}

#END CLASS
}
