<?php
/**
 * The implementation of the left ui element.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */

/**
 * Left block ui element.
 *
 * Default content is list of URL links.
 *
 * @package ndevinfo
 * @author Miroslav Kubelik (koubel@volny.cz)
 * @copyright Copyright (c) 2007 Miroslav Kubelik
 * @license http://opensource.org/licenses/gpl-license.php GNU GPL
 */
class LeftBlock
{
 /** title
  * @var string
  */
 public $title;

 /** name for the script template for the content
  * @var string
  */
 private $_contentTemplate;

 /** view object for the content
  * @var Zend_View_Interface
  */
 private $_contentView=null;
 
 /** list for urls, this for default content
  * @var Zend_View_Interface
  */
 private $_urlList = array();
 
//==============================================================================
/** setter for the {@link $_contentTemplate}
 * @var string script name
 */
public function setContentTemplate($script)
{
 $this->_contentTemplate = $script;
}

//==============================================================================
/** setter for the {@link $_contentView}
 * @var Zend_View_Interface $view view instance
 */
public function setContentView(Zend_View_Interface $view)
{
 $this->_contentView = $view;
}

//==============================================================================
/** Adds url into the url list.
 * @var array $urlArr one URL array in form ["urlName"]="urlLink"
 */
public function addUrl($urlArr)
{
 $this->_urlList[key($urlArr)] = current($urlArr);
}

//==============================================================================
/** Returns XHTML for whole block.
 * If are some items in the $_urlList, returns url list as content, if not
 * returns content defined by a view and template.
 * @return string XHTML content
 * @throws Exception when no from above mentioned possibilities hasn't been occured
 */
public function getContent()
{
 if (!empty( $this->_urlList))
  return $this->_getLinkedListContent();
  
 if (!empty($this->_contentTemplate) && !is_null($this->_contentView)) {
  return $this->_contentView->render($this->_contentTemplate);
 }

 throw new Exception("I don't know, how to render a left block content");
}

//==============================================================================
/** Returns XHTML for linked list a content.
 * @return string XHTML content
 */
private function _getLinkedListContent()
{
 $xhtml = "<ul>";
 foreach ($this->_urlList as $name => $url) {
  $xhtml.="<li><a href=\"".$url."\">".$name."</a></li>";
 }
 $xhtml .= "</ul>\n";
 
 return $xhtml;
}

#END CLASS
}
